from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSKArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSKArchives.proto',
  package='TSK',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSKArchives.proto\x12\x03TSK\x1a\x11TSPMessages.proto\"Z\n\x08TreeNode\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06object\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\x8c\x03\n\x0e\x43ommandHistory\x12\x12\n\nundo_count\x18\x01 \x02(\r\x12 \n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x14marked_redo_commands\x18\x03 \x03(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x35\n\x19pending_preflight_command\x18\x04 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12N\n\x1aselection_behavior_entries\x18\x05 \x03(\x0b\x32*.TSK.CommandHistory.SelectionBehaviorEntry\x12\x1c\n\x14\x66ixed_radar_13365177\x18\n \x01(\x08\x1am\n\x16SelectionBehaviorEntry\x12\x1f\n\x07\x63ommand\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1a\x63ommand_selection_behavior\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\x9a\x02\n\x1b\x43ollaborationCommandHistory\x12\x38\n\nundo_items\x18\x01 \x03(\x0b\x32$.TSK.CollaborationCommandHistoryItem\x12\x38\n\nredo_items\x18\x02 \x03(\x0b\x32$.TSK.CollaborationCommandHistoryItem\x12#\n\x10local_identifier\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12\x30\n\x18undo_transformer_entries\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x30\n\x18redo_transformer_entries\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\"\xca\x01\n\x1f\x43ollaborationCommandHistoryItem\x12\x1f\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x15\n\raction_string\x18\x02 \x01(\t\x12*\n\x12selection_behavior\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10\x63oalescing_group\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x11revision_sequence\x18\x05 \x01(\x04\"n\n*CollaborationCommandHistoryCoalescingGroup\x12\x1d\n\x05nodes\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x19\x64id_coalesce_all_commands\x18\x02 \x01(\x08\"Q\n.CollaborationCommandHistoryCoalescingGroupNode\x12\x1f\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\x8e\x01\nDCollaborationCommandHistoryOriginatingCommandAcknowledgementObserver\x12(\n\x10\x63oalescing_group\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x04node\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\xf6\x03\n\x0f\x44ocumentArchive\x12\x19\n\x11locale_identifier\x18\x04 \x01(\t\x12\x31\n\x19\x61nnotation_author_storage\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12,\n\x14\x61\x63tivity_log_entries\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1a\x63reation_locale_identifier\x18\t \x01(\t\x12(\n prevent_image_conversion_on_open\x18\n \x01(\x08\x12\x1b\n\x13has_floating_locale\x18\x0b \x01(\x08\x12\x1f\n\x17has_user_defined_locale\x18\x0c \x01(\x08\x12\x37\n\x1f\x63ollaboration_operation_history\x18\x0e \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n0should_measure_negatively_tracked_text_correctly\x18\x0f \x01(\x08\x12-\n%use_optimized_text_vertical_alignment\x18\x10 \x01(\x08\x12\x39\n\x12\x66ormatting_symbols\x18\x11 \x01(\x0b\x32\x1d.TSK.FormattingSymbolsArchive\"\xb9\n\n\x18\x46ormattingSymbolsArchive\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61lendar\x18\x02 \x01(\t\x12\x18\n\x10numbering_system\x18\x03 \x01(\t\x12\x0e\n\x06months\x18\x04 \x03(\t\x12\x19\n\x11standalone_months\x18\x05 \x03(\t\x12\x14\n\x0cshort_months\x18\x06 \x03(\t\x12\x1f\n\x17standalone_short_months\x18\x07 \x03(\t\x12\x10\n\x08weekdays\x18\x08 \x03(\t\x12\x1b\n\x13standalone_weekdays\x18\t \x03(\t\x12\x16\n\x0eshort_weekdays\x18\n \x03(\t\x12!\n\x19standalone_short_weekdays\x18\x0b \x03(\t\x12\x11\n\tam_symbol\x18\x0c \x01(\t\x12\x11\n\tpm_symbol\x18\r \x01(\t\x12\x13\n\x0btiny_months\x18\x0e \x03(\t\x12\x1e\n\x16standalone_tiny_months\x18\x0f \x03(\t\x12\x15\n\rtiny_weekdays\x18\x10 \x03(\t\x12 \n\x18standalone_tiny_weekdays\x18\x11 \x03(\t\x12\x10\n\x08quarters\x18\x12 \x03(\t\x12\x1b\n\x13standalone_quarters\x18\x13 \x03(\t\x12\x16\n\x0eshort_quarters\x18\x14 \x03(\t\x12!\n\x19standalone_short_quarters\x18\x15 \x03(\t\x12\x0c\n\x04\x65ras\x18\x16 \x03(\t\x12\x11\n\tlong_eras\x18\x17 \x03(\t\x12\x1a\n\x12short_date_pattern\x18\x18 \x01(\t\x12\x1b\n\x13medium_date_pattern\x18\x19 \x01(\t\x12\x19\n\x11long_date_pattern\x18\x1a \x01(\t\x12\x19\n\x11\x66ull_date_pattern\x18\x1b \x01(\t\x12\x1a\n\x12short_time_pattern\x18\x1c \x01(\t\x12\x1b\n\x13medium_time_pattern\x18\x1d \x01(\t\x12\x19\n\x11long_time_pattern\x18\x1e \x01(\t\x12\x19\n\x11\x66ull_time_pattern\x18\x1f \x01(\t\x12\x19\n\x11\x64\x65\x63imal_separator\x18  \x01(\t\x12\x1a\n\x12grouping_separator\x18! \x01(\t\x12\"\n\x1a\x63urrency_decimal_separator\x18\" \x01(\t\x12#\n\x1b\x63urrency_grouping_separator\x18# \x01(\t\x12\x11\n\tplus_sign\x18$ \x01(\t\x12\x12\n\nminus_sign\x18% \x01(\t\x12\x1a\n\x12\x65xponential_symbol\x18& \x01(\t\x12\x16\n\x0epercent_symbol\x18\' \x01(\t\x12\x18\n\x10per_mille_symbol\x18( \x01(\t\x12\x17\n\x0finfinity_symbol\x18) \x01(\t\x12\x12\n\nnan_symbol\x18* \x01(\t\x12\x17\n\x0f\x64\x65\x63imal_pattern\x18+ \x01(\t\x12\x1a\n\x12scientific_pattern\x18, \x01(\t\x12\x17\n\x0fpercent_pattern\x18- \x01(\t\x12\x18\n\x10\x63urrency_pattern\x18. \x01(\t\x12\x15\n\rcurrency_code\x18/ \x01(\t\x12\x46\n\x10\x63urrency_symbols\x18\x30 \x03(\x0b\x32,.TSK.FormattingSymbolsArchive.CurrencySymbol\x1a.\n\x0e\x43urrencySymbol\x12\x0c\n\x04\x63ode\x18\x01 \x02(\t\x12\x0e\n\x06symbol\x18\x02 \x02(\t\"\x8f\x01\n!DocumentSupportCollaborationState\x12\x35\n\x1d\x63ollaboration_command_history\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x1b\x63ollaboration_session_state\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"\x93\x04\n\x16\x44ocumentSupportArchive\x12\'\n\x0f\x63ommand_history\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x12\n\nundo_count\x18\x04 \x01(\r\x12\x12\n\nredo_count\x18\x05 \x01(\r\x12\x1a\n\x12undo_action_string\x18\x06 \x01(\t\x12\x1a\n\x12redo_action_string\x18\x07 \x01(\t\x12!\n\tweb_state\x18\x08 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x18is_in_collaboration_mode\x18\t \x01(\x08\x12\"\n\x1a\x61\x63tion_string_localization\x18\x0c \x01(\t\x12+\n\x13\x63ollaboration_state\x18\r \x01(\x0b\x32\x0e.TSP.Reference\x12>\n\"command_selection_behavior_history\x18\x02 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12&\n\nview_state\x18\x03 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x39\n\x1d\x63ollaboration_command_history\x18\n \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12\x37\n\x1b\x63ollaboration_session_state\x18\x0b \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\"\x85\x01\n\x10ViewStateArchive\x12\'\n\x0fview_state_root\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\x1a\x64ocument_revision_sequence\x18\x02 \x01(\x05\x12$\n\x1c\x64ocument_revision_identifier\x18\x03 \x01(\t\"\xf1\x01\n\x0e\x43ommandArchive\x12)\n\rundoRedoState\x18\x01 \x01(\x0b\x32\x0e.TSP.ReferenceB\x02\x18\x01\x12&\n\x0eundoCollection\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x15shadowed_by_transform\x18\x03 \x01(\x08\x12\x1a\n\x12shadowed_by_commit\x18\x04 \x01(\x08\x12\x0e\n\x06remote\x18\x05 \x01(\x08\x12&\n\x1eshould_hold_until_group_commit\x18\x06 \x01(\x08\x12\x19\n\x11server_originated\x18\x07 \x01(\x08\"\x9a\x01\n\x13\x43ommandGroupArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12 \n\x08\x63ommands\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12&\n\x0fprocess_results\x18\x03 \x01(\x0b\x32\r.TSP.IndexSet\x12\x15\n\raction_string\x18\x04 \x01(\t\"\xd7\x01\n\x1fInducedCommandCollectionArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12(\n\x10inducing_command\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10induced_commands\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12<\n%indexes_of_processed_induced_commands\x18\x04 \x01(\x0b\x32\r.TSP.IndexSet\"\xfc\x01\n\"PropagatedCommandCollectionArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12,\n\x14propagatable_command\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12+\n#propagatable_command_process_result\x18\x03 \x01(\x08\x12+\n\x13propagating_command\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12*\n\"propagating_command_process_result\x18\x05 \x01(\x08\"\xcb\x01\n\x17\x46inalCommandPairArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1f\n\x07\x63ommand\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x16\x63ommand_process_result\x18\x03 \x01(\x08\x12%\n\rfinal_command\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12$\n\x1c\x66inal_command_process_result\x18\x05 \x01(\x08\";\n\x17\x43ommandContainerArchive\x12 \n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"\xab\x02\n\x15ShuffleMappingArchive\x12\x13\n\x0bstart_index\x18\x01 \x02(\r\x12\x11\n\tend_index\x18\x02 \x02(\r\x12\x31\n\x07\x65ntries\x18\x03 \x03(\x0b\x32 .TSK.ShuffleMappingArchive.Entry\x12\x19\n\x0bis_vertical\x18\x04 \x01(\x08:\x04true\x12\x19\n\x11is_move_operation\x18\x05 \x01(\x08\x12\x19\n\x11\x66irst_moved_index\x18\x06 \x01(\r\x12\"\n\x1a\x64\x65stination_index_for_move\x18\x07 \x01(\r\x12\x1f\n\x17number_of_indexes_moved\x18\x08 \x01(\r\x1a!\n\x05\x45ntry\x12\x0c\n\x04\x66rom\x18\x01 \x02(\r\x12\n\n\x02to\x18\x02 \x02(\r\"I\n\x1eProgressiveCommandGroupArchive\x12\'\n\x05super\x18\x01 \x02(\x0b\x32\x18.TSK.CommandGroupArchive\"\xcc\n\n\x13\x46ormatStructArchive\x12\x13\n\x0b\x66ormat_type\x18\x01 \x02(\r\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x02 \x01(\r\x12\x15\n\rcurrency_code\x18\x03 \x01(\t\x12\x16\n\x0enegative_style\x18\x04 \x01(\r\x12 \n\x18show_thousands_separator\x18\x05 \x01(\x08\x12\x1c\n\x14use_accounting_style\x18\x06 \x01(\x08\x12\x16\n\x0e\x64uration_style\x18\x07 \x01(\r\x12\x0c\n\x04\x62\x61se\x18\x08 \x01(\r\x12\x13\n\x0b\x62\x61se_places\x18\t \x01(\r\x12\x1b\n\x13\x62\x61se_use_minus_sign\x18\n \x01(\x08\x12\x19\n\x11\x66raction_accuracy\x18\x0b \x01(\r\x12\x1c\n\x14suppress_date_format\x18\x0c \x01(\x08\x12\x1c\n\x14suppress_time_format\x18\r \x01(\x08\x12\x18\n\x10\x64\x61te_time_format\x18\x0e \x01(\t\x12\x1d\n\x15\x64uration_unit_largest\x18\x0f \x01(\r\x12\x1e\n\x16\x64uration_unit_smallest\x18\x10 \x01(\r\x12\x11\n\tcustom_id\x18\x11 \x01(\r\x12\x1c\n\x14\x63ustom_format_string\x18\x12 \x01(\t\x12\x14\n\x0cscale_factor\x18\x13 \x01(\x01\x12%\n\x1drequires_fraction_replacement\x18\x14 \x01(\x08\x12\x17\n\x0f\x63ontrol_minimum\x18\x15 \x01(\x01\x12\x17\n\x0f\x63ontrol_maximum\x18\x16 \x01(\x01\x12\x19\n\x11\x63ontrol_increment\x18\x17 \x01(\x01\x12\x1b\n\x13\x63ontrol_format_type\x18\x18 \x01(\r\x12\x1a\n\x12slider_orientation\x18\x19 \x01(\r\x12\x17\n\x0fslider_position\x18\x1a \x01(\r\x12\x15\n\rdecimal_width\x18\x1b \x01(\r\x12\x19\n\x11min_integer_width\x18\x1c \x01(\r\x12#\n\x1bnum_nonspace_integer_digits\x18\x1d \x01(\r\x12#\n\x1bnum_nonspace_decimal_digits\x18\x1e \x01(\r\x12%\n\x1dindex_from_right_last_integer\x18\x1f \x01(\r\x12\x1c\n\x14interstitial_strings\x18  \x03(\t\x12\x33\n\x1cinters_str_insertion_indexes\x18! \x01(\x0b\x32\r.TSP.IndexSet\x12\x1f\n\x17num_hash_decimal_digits\x18\" \x01(\r\x12 \n\x18total_num_decimal_digits\x18# \x01(\r\x12\x12\n\nis_complex\x18$ \x01(\x08\x12\x1e\n\x16\x63ontains_integer_token\x18% \x01(\x08\x12*\n\"multiple_choice_list_initial_value\x18& \x01(\r\x12\x1f\n\x17multiple_choice_list_id\x18\' \x01(\r\x12$\n\x1cuse_automatic_duration_units\x18( \x01(\x08\x12\x1d\n\ncustom_uid\x18) \x01(\x0b\x32\t.TSP.UUID\x12/\n\rcustom_format\x18* \x01(\x0b\x32\x18.TSK.CustomFormatArchive\x12\x16\n\x0euses_plus_sign\x18+ \x01(\x08\x12\x18\n\x10\x62ool_true_string\x18, \x01(\t\x12\x19\n\x11\x62ool_false_string\x18- \x01(\t*\x07\x08\x90N\x10\xa0\x9c\x01\"\xcf\x02\n\x13\x43ustomFormatArchive\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x1b\n\x13\x66ormat_type_pre_bnc\x18\x02 \x02(\r\x12\x30\n\x0e\x64\x65\x66\x61ult_format\x18\x03 \x02(\x0b\x32\x18.TSK.FormatStructArchive\x12\x36\n\nconditions\x18\x04 \x03(\x0b\x32\".TSK.CustomFormatArchive.Condition\x12\x13\n\x0b\x66ormat_type\x18\x05 \x01(\r\x1a\x8d\x01\n\tCondition\x12\x16\n\x0e\x63ondition_type\x18\x01 \x02(\r\x12\x17\n\x0f\x63ondition_value\x18\x02 \x01(\x02\x12\x32\n\x10\x63ondition_format\x18\x03 \x02(\x0b\x32\x18.TSK.FormatStructArchive\x12\x1b\n\x13\x63ondition_value_dbl\x18\x04 \x01(\x01\"e\n\x17\x43ustomFormatListArchive\x12\x18\n\x05uuids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x30\n\x0e\x63ustom_formats\x18\x02 \x03(\x0b\x32\x18.TSK.CustomFormatArchive\"o\n\x17\x41nnotationAuthorArchive\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x05\x63olor\x18\x02 \x01(\x0b\x32\n.TSP.Color\x12\x11\n\tpublic_id\x18\x03 \x01(\t\x12\x18\n\x10is_public_author\x18\x04 \x01(\x08\"O\n\x1d\x44\x65precatedChangeAuthorArchive\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x0c\x63hange_color\x18\x02 \x01(\x0b\x32\n.TSP.Color\"K\n\x1e\x41nnotationAuthorStorageArchive\x12)\n\x11\x61nnotation_author\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"\xb1\x01\n&SetAnnotationAuthorColorCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x11\x61nnotation_author\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x19\n\x05\x63olor\x18\x03 \x01(\x0b\x32\n.TSP.Color\x12\x1d\n\told_color\x18\x04 \x01(\x0b\x32\n.TSP.Color\"\xef\x03\n\x1f\x43ommandSelectionBehaviorArchive\x12\x35\n\x12\x61rchived_selection\x18\x08 \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12\x39\n\x16\x61rchived_old_selection\x18\x01 \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12\x39\n\x16\x61rchived_new_selection\x18\x02 \x01(\x0b\x32\x19.TSK.SelectionPathArchive\x12\x17\n\x0fselection_flags\x18\x03 \x01(\x04\x12*\n\"additional_forward_selection_flags\x18\x04 \x01(\x04\x12*\n\"additional_reverse_selection_flags\x18\x05 \x01(\x04\x12:\n\"forward_selection_path_transformer\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12:\n\"reverse_selection_path_transformer\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x36\n\x1e\x61\x64\x64itional_selection_behaviors\x18\t \x03(\x0b\x32\x0e.TSP.Reference\"Q\n\x1fSelectionPathTransformerArchive\x12.\n\x16selection_transformers\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"B\n\x14SelectionPathArchive\x12*\n\x12ordered_selections\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"A\n\x18\x44ocumentSelectionArchive\x12%\n\rdocument_root\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"1\n\x0fIdOperationArgs\x12\x1e\n\x07id_path\x18\x01 \x02(\x0b\x32\r.TSP.UUIDPath\"H\n\x12\x41\x64\x64IdOperationArgs\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSK.IdOperationArgs\x12\r\n\x05index\x18\x02 \x02(\x05\"K\n\x15RemoveIdOperationArgs\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSK.IdOperationArgs\x12\r\n\x05index\x18\x02 \x02(\x05\"e\n\x18RearrangeIdOperationArgs\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSK.IdOperationArgs\x12\x12\n\nfrom_index\x18\x02 \x02(\x05\x12\x10\n\x08to_index\x18\x03 \x02(\x05\"e\n\x18IdPlacementOperationArgs\x12#\n\x05super\x18\x01 \x02(\x0b\x32\x14.TSK.IdOperationArgs\x12\x12\n\nfrom_index\x18\x02 \x02(\x05\x12\x10\n\x08to_index\x18\x03 \x02(\x05\"8\n\x12NullCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"?\n\x19GroupCommitCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"L\n&UpgradeDocPostProcessingCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"R\n,InducedCommandCollectionCommitCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"X\n2ExecuteTestBetweenRollbackAndReapplyCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xb0\x02\n\'ChangeDocumentPackageTypeCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12R\n\x10new_package_type\x18\x02 \x02(\x0e\x32\x38.TSK.ChangeDocumentPackageTypeCommandArchive.PackageType\x12R\n\x10old_package_type\x18\x03 \x02(\x0e\x32\x38.TSK.ChangeDocumentPackageTypeCommandArchive.PackageType\"9\n\x0bPackageType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\r\n\tDirectory\x10\x01\x12\x0e\n\nSingleFile\x10\x02\"c\n(CreateLocalStorageSnapshotCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x13\n\x0bsnapshot_id\x18\x02 \x01(\t\"H\n\"BlockDiffsAtCurrentRevisionCommand\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\">\n\x0cRangeAddress\x12\x1a\n\x12\x61\x64\x64ress_identifier\x18\x01 \x03(\x04\x12\x12\n\nrange_list\x18\x02 \x03(\r\"\xea\x03\n\tOperation\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32\x1c.TSK.Operation.OperationType:\x0cReplaceRange\x12\x0c\n\x04noop\x18\x02 \x01(\x08\x12\x1a\n\x12\x61\x64\x64ress_identifier\x18\x03 \x03(\x06\x12\x18\n\rinsert_length\x18\x04 \x01(\x04:\x01\x31\x12(\n preserve_lower_priority_location\x18\x05 \x01(\x08\x12\x12\n\nrange_list\x18\x06 \x03(\r\x12\x1d\n\x12transform_behavior\x18\x07 \x01(\r:\x01\x37\x12\x13\n\x0bproperty_id\x18\x08 \x01(\r\x12\x16\n\nfrom_index\x18\t \x01(\x05:\x02-1\x12\x14\n\x08to_index\x18\n \x01(\x05:\x02-1\x12\x12\n\ndominating\x18\x0b \x01(\x08\x12\x18\n\x0cobject_count\x18\x0c \x01(\x05:\x02-1\x12\x1c\n\x14object_counter_space\x18\r \x01(\x05\"s\n\rOperationType\x12\x07\n\x03\x41\x64\x64\x10\x00\x12\n\n\x06Remove\x10\x01\x12\r\n\tPlacement\x10\x02\x12\r\n\tRearrange\x10\x03\x12\x0c\n\x08UpdateId\x10\x04\x12\x0f\n\x0bUpdateRange\x10\x05\x12\x10\n\x0cReplaceRange\x10\x06\"S\n\x14OperationTransformer\x12\x17\n\x0fhigher_priority\x18\x01 \x02(\x08\x12\"\n\noperations\x18\x02 \x03(\x0b\x32\x0e.TSK.Operation\"k\n\x10TransformerEntry\x12\x10\n\x08sequence\x18\x01 \x02(\x04\x12\x15\n\rcreation_time\x18\x02 \x02(\x01\x12.\n\x0btransformer\x18\x03 \x02(\x0b\x32\x19.TSK.OperationTransformer\"\x98\x02\n\x18OutgoingCommandQueueItem\x12\x1f\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12:\n2serialized_json_without_data_base64_encoded_string\x18\x02 \x01(\t\x12L\n0serialized_json_without_data_base64_encoded_data\x18\x04 \x01(\x0b\x32\x12.TSP.DataReference\x12Q\n\x18uuid_to_data_map_entries\x18\x03 \x03(\x0b\x32/.TSK.OutgoingCommandQueueItemUUIDToDataMapEntry\"g\n*OutgoingCommandQueueItemUUIDToDataMapEntry\x12\x17\n\x04uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12 \n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\x12.TSP.DataReference\"\xb7\n\n!CollaborationDocumentSessionState\x12\x18\n\x10\x63ollaborator_ids\x18\x01 \x03(\t\x12\x30\n\x18rsvp_command_queue_items\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12?\n\'collaborator_cursor_transformer_entries\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12J\n2acknowledged_commands_pending_resume_process_diffs\x18\x05 \x03(\x0b\x32\x0e.TSP.Reference\x12I\n1unprocessed_commands_pending_resume_process_diffs\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12u\n(command_acknowledgement_observer_entries\x18\x07 \x03(\x0b\x32\x43.TSK.CollaborationDocumentSessionState.AcknowledgementObserverEntry\x12O\n7transformer_from_unprocessed_command_operations_entries\x18\x08 \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n*mailbox_request_document_revision_sequence\x18\n \x01(\x05\x12\x34\n,mailbox_request_document_revision_identifier\x18\x0b \x01(\t\x12N\nFlast_send_pending_command_queue_item_was_moved_from_rsvp_command_queue\x18\x0c \x01(\x08\x12)\n!last_command_send_marker_sequence\x18\r \x01(\x05\x12+\n#last_command_send_marker_identifier\x18\x0e \x01(\t\x12R\n:skipped_acknowledged_commands_pending_resume_process_diffs\x18\x0f \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1flast_too_old_command_identifier\x18\x10 \x01(\x0b\x32\t.TSP.UUID\x12R\n:unprocessed_operation_entries_pending_resume_process_diffs\x18\x11 \x01(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1asend_pending_command_queue\x18\x12 \x01(\x0b\x32\x0e.TSP.Reference\x12G\n?count_of_send_pending_command_queue_items_moved_from_rsvp_queue\x18\x13 \x01(\x04\x12\x41\n.last_enqueued_document_load_command_identifier\x18\x14 \x01(\x0b\x32\t.TSP.UUID\x1ax\n\x1c\x41\x63knowledgementObserverEntry\x12%\n\x12\x63ommand_identifier\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x31\n\x19\x61\x63knowledgement_observers\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x85\x01\n\x18NativeContentDescription\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x02 \x01(\t\x12\x13\n\x0b\x64ocument_id\x18\x03 \x01(\t\x12-\n\x15\x64rawable_descriptions\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\x83\x03\n\x1cStructuredTextImportSettings\x12+\n\x04type\x18\x01 \x02(\x0e\x32\x1d.TSK.StructuredTextImportType\x12\x14\n\x0cstarting_row\x18\x02 \x02(\x05\x12\x1a\n\x12\x64\x65\x63imal_separators\x18\x03 \x03(\t\x12\x1c\n\x14thousands_separators\x18\x04 \x03(\t\x12\"\n\x1atranspose_rows_and_columns\x18\x05 \x01(\x08\x12\x12\n\ndelimiters\x18\x06 \x03(\t\x12\x17\n\x0ftext_qualifiers\x18\x07 \x03(\t\x12\x1c\n\x14\x63ollapse_consecutive\x18\x08 \x01(\x08\x12%\n\x0e\x63olumn_offsets\x18\t \x01(\x0b\x32\r.TSP.IndexSet\x12\x1c\n\x14\x61utomatic_delimiters\x18\n \x01(\x08\x12\x19\n\x11\x61utomatic_offsets\x18\x0b \x01(\x08\x12\x17\n\x0fsource_encoding\x18\x0c \x01(\x04\"\xe2\x01\n&OperationStorageCommandOperationsEntry\x12\x36\n.command_identifier_same_as_revision_identifier\x18\x01 \x01(\x08\x12\x1a\n\x12\x63ommand_identifier\x18\x02 \x03(\x06\x12\"\n\noperations\x18\x03 \x03(\x0b\x32\x0e.TSK.Operation\x12\x19\n\x11server_originated\x18\x04 \x01(\x08\x12%\n\x1d\x63oalesced_command_entry_count\x18\x05 \x01(\x04\"\xfd\x01\n\x15OperationStorageEntry\x12$\n\x1c\x64ocument_revision_identifier\x18\x01 \x03(\x06\x12(\n document_revision_sequence_delta\x18\x02 \x01(\x05\x12N\n\x19\x63ommand_operation_entries\x18\x03 \x03(\x0b\x32+.TSK.OperationStorageCommandOperationsEntry\x12!\n\x19\x66irst_entry_creation_time\x18\x04 \x01(\x01\x12!\n\x19\x63reation_time_diff_bucket\x18\x05 \x01(\x05\"B\n\x1aOperationStorageEntryArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"\x92\x02\n!OperationStorageEntryArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12,\n\x08\x65lements\x18\x02 \x03(\x0b\x32\x1a.TSK.OperationStorageEntry\x12\x36\n.last_document_revision_sequence_before_segment\x18\x03 \x01(\x05\x12\'\n\x1flast_document_revision_sequence\x18\x04 \x01(\x05\x12)\n!segment_first_entry_creation_time\x18\x05 \x01(\x01\"\xd7\x03\n\x10OperationStorage\x12\x1f\n\x07\x65ntries\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x0foperation_count\x18\x02 \x02(\x04\x12\'\n\x1flast_document_revision_sequence\x18\x03 \x01(\x05\x12)\n!last_document_revision_identifier\x18\x04 \x03(\x06\x12\x42\n:last_unskippable_document_revision_before_entries_sequence\x18\x05 \x01(\x05\x12\x44\n<last_unskippable_document_revision_before_entries_identifier\x18\x06 \x03(\x06\x12>\n6last_unskippable_document_revision_in_entries_sequence\x18\x07 \x01(\x05\x12@\n8last_unskippable_document_revision_in_entries_identifier\x18\x08 \x03(\x06\x12)\n\x12\x64\x61ys_with_an_entry\x18\t \x01(\x0b\x32\r.TSP.IndexSet\"I\n\x14OutgoingCommandQueue\x12\x31\n\x12large_object_array\x18\x01 \x01(\x0b\x32\x15.TSP.LargeObjectArray\"_\n\x1bOutgoingCommandQueueSegment\x12@\n\x1alarge_object_array_segment\x18\x01 \x01(\x0b\x32\x1c.TSP.LargeObjectArraySegment\"\xc4\x03\n\x13\x44\x61taReferenceRecord\x12q\n-added_container_uuid_to_referenced_data_pairs\x18\x01 \x03(\x0b\x32:.TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair\x12s\n/removed_container_uuid_to_referenced_data_pairs\x18\x02 \x03(\x0b\x32:.TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair\x12\x36\n\x1aunbounded_referenced_datas\x18\x03 \x03(\x0b\x32\x12.TSP.DataReference\x1a\x8c\x01\n!ContainerUUIDToReferencedDataPair\x12!\n\x0e\x63ontainer_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12+\n\x0freferenced_data\x18\x02 \x02(\x0b\x32\x12.TSP.DataReference\x12\x17\n\x0freference_count\x18\x03 \x02(\r*g\n\x18StructuredTextImportType\x12\x16\n\x12ImportType_UNKNOWN\x10\x00\x12\x18\n\x14ImportType_DELIMITED\x10\x01\x12\x19\n\x15ImportType_FIXEDWIDTH\x10\x02')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,])

_STRUCTUREDTEXTIMPORTTYPE = _descriptor.EnumDescriptor(
  name='StructuredTextImportType',
  full_name='TSK.StructuredTextImportType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ImportType_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImportType_DELIMITED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ImportType_FIXEDWIDTH', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14711,
  serialized_end=14814,
)
_sym_db.RegisterEnumDescriptor(_STRUCTUREDTEXTIMPORTTYPE)

StructuredTextImportType = enum_type_wrapper.EnumTypeWrapper(_STRUCTUREDTEXTIMPORTTYPE)
ImportType_UNKNOWN = 0
ImportType_DELIMITED = 1
ImportType_FIXEDWIDTH = 2


_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE = _descriptor.EnumDescriptor(
  name='PackageType',
  full_name='TSK.ChangeDocumentPackageTypeCommandArchive.PackageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Default', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Directory', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SingleFile', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9543,
  serialized_end=9600,
)
_sym_db.RegisterEnumDescriptor(_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE)

_OPERATION_OPERATIONTYPE = _descriptor.EnumDescriptor(
  name='OperationType',
  full_name='TSK.Operation.OperationType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Add', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Remove', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Placement', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Rearrange', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UpdateId', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UpdateRange', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ReplaceRange', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=10217,
  serialized_end=10332,
)
_sym_db.RegisterEnumDescriptor(_OPERATION_OPERATIONTYPE)


_TREENODE = _descriptor.Descriptor(
  name='TreeNode',
  full_name='TSK.TreeNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSK.TreeNode.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='children', full_name='TSK.TreeNode.children', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSK.TreeNode.object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=135,
)


_COMMANDHISTORY_SELECTIONBEHAVIORENTRY = _descriptor.Descriptor(
  name='SelectionBehaviorEntry',
  full_name='TSK.CommandHistory.SelectionBehaviorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='TSK.CommandHistory.SelectionBehaviorEntry.command', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_selection_behavior', full_name='TSK.CommandHistory.SelectionBehaviorEntry.command_selection_behavior', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=534,
)

_COMMANDHISTORY = _descriptor.Descriptor(
  name='CommandHistory',
  full_name='TSK.CommandHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='undo_count', full_name='TSK.CommandHistory.undo_count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commands', full_name='TSK.CommandHistory.commands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='marked_redo_commands', full_name='TSK.CommandHistory.marked_redo_commands', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending_preflight_command', full_name='TSK.CommandHistory.pending_preflight_command', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_behavior_entries', full_name='TSK.CommandHistory.selection_behavior_entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fixed_radar_13365177', full_name='TSK.CommandHistory.fixed_radar_13365177', index=5,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDHISTORY_SELECTIONBEHAVIORENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=534,
)


_COLLABORATIONCOMMANDHISTORY = _descriptor.Descriptor(
  name='CollaborationCommandHistory',
  full_name='TSK.CollaborationCommandHistory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='undo_items', full_name='TSK.CollaborationCommandHistory.undo_items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_items', full_name='TSK.CollaborationCommandHistory.redo_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_identifier', full_name='TSK.CollaborationCommandHistory.local_identifier', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_transformer_entries', full_name='TSK.CollaborationCommandHistory.undo_transformer_entries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_transformer_entries', full_name='TSK.CollaborationCommandHistory.redo_transformer_entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=819,
)


_COLLABORATIONCOMMANDHISTORYITEM = _descriptor.Descriptor(
  name='CollaborationCommandHistoryItem',
  full_name='TSK.CollaborationCommandHistoryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='TSK.CollaborationCommandHistoryItem.command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string', full_name='TSK.CollaborationCommandHistoryItem.action_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_behavior', full_name='TSK.CollaborationCommandHistoryItem.selection_behavior', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalescing_group', full_name='TSK.CollaborationCommandHistoryItem.coalescing_group', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision_sequence', full_name='TSK.CollaborationCommandHistoryItem.revision_sequence', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=822,
  serialized_end=1024,
)


_COLLABORATIONCOMMANDHISTORYCOALESCINGGROUP = _descriptor.Descriptor(
  name='CollaborationCommandHistoryCoalescingGroup',
  full_name='TSK.CollaborationCommandHistoryCoalescingGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='TSK.CollaborationCommandHistoryCoalescingGroup.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='did_coalesce_all_commands', full_name='TSK.CollaborationCommandHistoryCoalescingGroup.did_coalesce_all_commands', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1026,
  serialized_end=1136,
)


_COLLABORATIONCOMMANDHISTORYCOALESCINGGROUPNODE = _descriptor.Descriptor(
  name='CollaborationCommandHistoryCoalescingGroupNode',
  full_name='TSK.CollaborationCommandHistoryCoalescingGroupNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='TSK.CollaborationCommandHistoryCoalescingGroupNode.command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1219,
)


_COLLABORATIONCOMMANDHISTORYORIGINATINGCOMMANDACKNOWLEDGEMENTOBSERVER = _descriptor.Descriptor(
  name='CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver',
  full_name='TSK.CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coalescing_group', full_name='TSK.CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver.coalescing_group', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='TSK.CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1222,
  serialized_end=1364,
)


_DOCUMENTARCHIVE = _descriptor.Descriptor(
  name='DocumentArchive',
  full_name='TSK.DocumentArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='locale_identifier', full_name='TSK.DocumentArchive.locale_identifier', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_author_storage', full_name='TSK.DocumentArchive.annotation_author_storage', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='activity_log_entries', full_name='TSK.DocumentArchive.activity_log_entries', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_locale_identifier', full_name='TSK.DocumentArchive.creation_locale_identifier', index=3,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prevent_image_conversion_on_open', full_name='TSK.DocumentArchive.prevent_image_conversion_on_open', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_floating_locale', full_name='TSK.DocumentArchive.has_floating_locale', index=5,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='has_user_defined_locale', full_name='TSK.DocumentArchive.has_user_defined_locale', index=6,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaboration_operation_history', full_name='TSK.DocumentArchive.collaboration_operation_history', index=7,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_measure_negatively_tracked_text_correctly', full_name='TSK.DocumentArchive.should_measure_negatively_tracked_text_correctly', index=8,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_optimized_text_vertical_alignment', full_name='TSK.DocumentArchive.use_optimized_text_vertical_alignment', index=9,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatting_symbols', full_name='TSK.DocumentArchive.formatting_symbols', index=10,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1869,
)


_FORMATTINGSYMBOLSARCHIVE_CURRENCYSYMBOL = _descriptor.Descriptor(
  name='CurrencySymbol',
  full_name='TSK.FormattingSymbolsArchive.CurrencySymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='TSK.FormattingSymbolsArchive.CurrencySymbol.code', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='TSK.FormattingSymbolsArchive.CurrencySymbol.symbol', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3163,
  serialized_end=3209,
)

_FORMATTINGSYMBOLSARCHIVE = _descriptor.Descriptor(
  name='FormattingSymbolsArchive',
  full_name='TSK.FormattingSymbolsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='TSK.FormattingSymbolsArchive.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calendar', full_name='TSK.FormattingSymbolsArchive.calendar', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numbering_system', full_name='TSK.FormattingSymbolsArchive.numbering_system', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='months', full_name='TSK.FormattingSymbolsArchive.months', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_months', full_name='TSK.FormattingSymbolsArchive.standalone_months', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_months', full_name='TSK.FormattingSymbolsArchive.short_months', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_short_months', full_name='TSK.FormattingSymbolsArchive.standalone_short_months', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weekdays', full_name='TSK.FormattingSymbolsArchive.weekdays', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_weekdays', full_name='TSK.FormattingSymbolsArchive.standalone_weekdays', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_weekdays', full_name='TSK.FormattingSymbolsArchive.short_weekdays', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_short_weekdays', full_name='TSK.FormattingSymbolsArchive.standalone_short_weekdays', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='am_symbol', full_name='TSK.FormattingSymbolsArchive.am_symbol', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pm_symbol', full_name='TSK.FormattingSymbolsArchive.pm_symbol', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiny_months', full_name='TSK.FormattingSymbolsArchive.tiny_months', index=13,
      number=14, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_tiny_months', full_name='TSK.FormattingSymbolsArchive.standalone_tiny_months', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tiny_weekdays', full_name='TSK.FormattingSymbolsArchive.tiny_weekdays', index=15,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_tiny_weekdays', full_name='TSK.FormattingSymbolsArchive.standalone_tiny_weekdays', index=16,
      number=17, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quarters', full_name='TSK.FormattingSymbolsArchive.quarters', index=17,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_quarters', full_name='TSK.FormattingSymbolsArchive.standalone_quarters', index=18,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_quarters', full_name='TSK.FormattingSymbolsArchive.short_quarters', index=19,
      number=20, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='standalone_short_quarters', full_name='TSK.FormattingSymbolsArchive.standalone_short_quarters', index=20,
      number=21, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eras', full_name='TSK.FormattingSymbolsArchive.eras', index=21,
      number=22, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_eras', full_name='TSK.FormattingSymbolsArchive.long_eras', index=22,
      number=23, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_date_pattern', full_name='TSK.FormattingSymbolsArchive.short_date_pattern', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='medium_date_pattern', full_name='TSK.FormattingSymbolsArchive.medium_date_pattern', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_date_pattern', full_name='TSK.FormattingSymbolsArchive.long_date_pattern', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_date_pattern', full_name='TSK.FormattingSymbolsArchive.full_date_pattern', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='short_time_pattern', full_name='TSK.FormattingSymbolsArchive.short_time_pattern', index=27,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='medium_time_pattern', full_name='TSK.FormattingSymbolsArchive.medium_time_pattern', index=28,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='long_time_pattern', full_name='TSK.FormattingSymbolsArchive.long_time_pattern', index=29,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_time_pattern', full_name='TSK.FormattingSymbolsArchive.full_time_pattern', index=30,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_separator', full_name='TSK.FormattingSymbolsArchive.decimal_separator', index=31,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='grouping_separator', full_name='TSK.FormattingSymbolsArchive.grouping_separator', index=32,
      number=33, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_decimal_separator', full_name='TSK.FormattingSymbolsArchive.currency_decimal_separator', index=33,
      number=34, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_grouping_separator', full_name='TSK.FormattingSymbolsArchive.currency_grouping_separator', index=34,
      number=35, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plus_sign', full_name='TSK.FormattingSymbolsArchive.plus_sign', index=35,
      number=36, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='minus_sign', full_name='TSK.FormattingSymbolsArchive.minus_sign', index=36,
      number=37, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exponential_symbol', full_name='TSK.FormattingSymbolsArchive.exponential_symbol', index=37,
      number=38, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_symbol', full_name='TSK.FormattingSymbolsArchive.percent_symbol', index=38,
      number=39, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_mille_symbol', full_name='TSK.FormattingSymbolsArchive.per_mille_symbol', index=39,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='infinity_symbol', full_name='TSK.FormattingSymbolsArchive.infinity_symbol', index=40,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nan_symbol', full_name='TSK.FormattingSymbolsArchive.nan_symbol', index=41,
      number=42, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_pattern', full_name='TSK.FormattingSymbolsArchive.decimal_pattern', index=42,
      number=43, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scientific_pattern', full_name='TSK.FormattingSymbolsArchive.scientific_pattern', index=43,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='percent_pattern', full_name='TSK.FormattingSymbolsArchive.percent_pattern', index=44,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_pattern', full_name='TSK.FormattingSymbolsArchive.currency_pattern', index=45,
      number=46, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TSK.FormattingSymbolsArchive.currency_code', index=46,
      number=47, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_symbols', full_name='TSK.FormattingSymbolsArchive.currency_symbols', index=47,
      number=48, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FORMATTINGSYMBOLSARCHIVE_CURRENCYSYMBOL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1872,
  serialized_end=3209,
)


_DOCUMENTSUPPORTCOLLABORATIONSTATE = _descriptor.Descriptor(
  name='DocumentSupportCollaborationState',
  full_name='TSK.DocumentSupportCollaborationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collaboration_command_history', full_name='TSK.DocumentSupportCollaborationState.collaboration_command_history', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaboration_session_state', full_name='TSK.DocumentSupportCollaborationState.collaboration_session_state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3212,
  serialized_end=3355,
)


_DOCUMENTSUPPORTARCHIVE = _descriptor.Descriptor(
  name='DocumentSupportArchive',
  full_name='TSK.DocumentSupportArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_history', full_name='TSK.DocumentSupportArchive.command_history', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_count', full_name='TSK.DocumentSupportArchive.undo_count', index=1,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_count', full_name='TSK.DocumentSupportArchive.redo_count', index=2,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_action_string', full_name='TSK.DocumentSupportArchive.undo_action_string', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='redo_action_string', full_name='TSK.DocumentSupportArchive.redo_action_string', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='web_state', full_name='TSK.DocumentSupportArchive.web_state', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_in_collaboration_mode', full_name='TSK.DocumentSupportArchive.is_in_collaboration_mode', index=6,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string_localization', full_name='TSK.DocumentSupportArchive.action_string_localization', index=7,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaboration_state', full_name='TSK.DocumentSupportArchive.collaboration_state', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_selection_behavior_history', full_name='TSK.DocumentSupportArchive.command_selection_behavior_history', index=9,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view_state', full_name='TSK.DocumentSupportArchive.view_state', index=10,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaboration_command_history', full_name='TSK.DocumentSupportArchive.collaboration_command_history', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaboration_session_state', full_name='TSK.DocumentSupportArchive.collaboration_session_state', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3358,
  serialized_end=3889,
)


_VIEWSTATEARCHIVE = _descriptor.Descriptor(
  name='ViewStateArchive',
  full_name='TSK.ViewStateArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_state_root', full_name='TSK.ViewStateArchive.view_state_root', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_revision_sequence', full_name='TSK.ViewStateArchive.document_revision_sequence', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_revision_identifier', full_name='TSK.ViewStateArchive.document_revision_identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3892,
  serialized_end=4025,
)


_COMMANDARCHIVE = _descriptor.Descriptor(
  name='CommandArchive',
  full_name='TSK.CommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='undoRedoState', full_name='TSK.CommandArchive.undoRedoState', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undoCollection', full_name='TSK.CommandArchive.undoCollection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadowed_by_transform', full_name='TSK.CommandArchive.shadowed_by_transform', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shadowed_by_commit', full_name='TSK.CommandArchive.shadowed_by_commit', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote', full_name='TSK.CommandArchive.remote', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_hold_until_group_commit', full_name='TSK.CommandArchive.should_hold_until_group_commit', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_originated', full_name='TSK.CommandArchive.server_originated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4028,
  serialized_end=4269,
)


_COMMANDGROUPARCHIVE = _descriptor.Descriptor(
  name='CommandGroupArchive',
  full_name='TSK.CommandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.CommandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commands', full_name='TSK.CommandGroupArchive.commands', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_results', full_name='TSK.CommandGroupArchive.process_results', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action_string', full_name='TSK.CommandGroupArchive.action_string', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4272,
  serialized_end=4426,
)


_INDUCEDCOMMANDCOLLECTIONARCHIVE = _descriptor.Descriptor(
  name='InducedCommandCollectionArchive',
  full_name='TSK.InducedCommandCollectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.InducedCommandCollectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inducing_command', full_name='TSK.InducedCommandCollectionArchive.inducing_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='induced_commands', full_name='TSK.InducedCommandCollectionArchive.induced_commands', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexes_of_processed_induced_commands', full_name='TSK.InducedCommandCollectionArchive.indexes_of_processed_induced_commands', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4429,
  serialized_end=4644,
)


_PROPAGATEDCOMMANDCOLLECTIONARCHIVE = _descriptor.Descriptor(
  name='PropagatedCommandCollectionArchive',
  full_name='TSK.PropagatedCommandCollectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.PropagatedCommandCollectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propagatable_command', full_name='TSK.PropagatedCommandCollectionArchive.propagatable_command', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propagatable_command_process_result', full_name='TSK.PropagatedCommandCollectionArchive.propagatable_command_process_result', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propagating_command', full_name='TSK.PropagatedCommandCollectionArchive.propagating_command', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='propagating_command_process_result', full_name='TSK.PropagatedCommandCollectionArchive.propagating_command_process_result', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4647,
  serialized_end=4899,
)


_FINALCOMMANDPAIRARCHIVE = _descriptor.Descriptor(
  name='FinalCommandPairArchive',
  full_name='TSK.FinalCommandPairArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.FinalCommandPairArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='TSK.FinalCommandPairArchive.command', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_process_result', full_name='TSK.FinalCommandPairArchive.command_process_result', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_command', full_name='TSK.FinalCommandPairArchive.final_command', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_command_process_result', full_name='TSK.FinalCommandPairArchive.final_command_process_result', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4902,
  serialized_end=5105,
)


_COMMANDCONTAINERARCHIVE = _descriptor.Descriptor(
  name='CommandContainerArchive',
  full_name='TSK.CommandContainerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='TSK.CommandContainerArchive.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5107,
  serialized_end=5166,
)


_SHUFFLEMAPPINGARCHIVE_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSK.ShuffleMappingArchive.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='TSK.ShuffleMappingArchive.Entry.from', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='TSK.ShuffleMappingArchive.Entry.to', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5435,
  serialized_end=5468,
)

_SHUFFLEMAPPINGARCHIVE = _descriptor.Descriptor(
  name='ShuffleMappingArchive',
  full_name='TSK.ShuffleMappingArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_index', full_name='TSK.ShuffleMappingArchive.start_index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_index', full_name='TSK.ShuffleMappingArchive.end_index', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSK.ShuffleMappingArchive.entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_vertical', full_name='TSK.ShuffleMappingArchive.is_vertical', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_move_operation', full_name='TSK.ShuffleMappingArchive.is_move_operation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_moved_index', full_name='TSK.ShuffleMappingArchive.first_moved_index', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_index_for_move', full_name='TSK.ShuffleMappingArchive.destination_index_for_move', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='number_of_indexes_moved', full_name='TSK.ShuffleMappingArchive.number_of_indexes_moved', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SHUFFLEMAPPINGARCHIVE_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5169,
  serialized_end=5468,
)


_PROGRESSIVECOMMANDGROUPARCHIVE = _descriptor.Descriptor(
  name='ProgressiveCommandGroupArchive',
  full_name='TSK.ProgressiveCommandGroupArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.ProgressiveCommandGroupArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5470,
  serialized_end=5543,
)


_FORMATSTRUCTARCHIVE = _descriptor.Descriptor(
  name='FormatStructArchive',
  full_name='TSK.FormatStructArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='format_type', full_name='TSK.FormatStructArchive.format_type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_places', full_name='TSK.FormatStructArchive.decimal_places', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='TSK.FormatStructArchive.currency_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='negative_style', full_name='TSK.FormatStructArchive.negative_style', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='show_thousands_separator', full_name='TSK.FormatStructArchive.show_thousands_separator', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_accounting_style', full_name='TSK.FormatStructArchive.use_accounting_style', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_style', full_name='TSK.FormatStructArchive.duration_style', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base', full_name='TSK.FormatStructArchive.base', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_places', full_name='TSK.FormatStructArchive.base_places', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='base_use_minus_sign', full_name='TSK.FormatStructArchive.base_use_minus_sign', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fraction_accuracy', full_name='TSK.FormatStructArchive.fraction_accuracy', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suppress_date_format', full_name='TSK.FormatStructArchive.suppress_date_format', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suppress_time_format', full_name='TSK.FormatStructArchive.suppress_time_format', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_time_format', full_name='TSK.FormatStructArchive.date_time_format', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_unit_largest', full_name='TSK.FormatStructArchive.duration_unit_largest', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_unit_smallest', full_name='TSK.FormatStructArchive.duration_unit_smallest', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_id', full_name='TSK.FormatStructArchive.custom_id', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format_string', full_name='TSK.FormatStructArchive.custom_format_string', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_factor', full_name='TSK.FormatStructArchive.scale_factor', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requires_fraction_replacement', full_name='TSK.FormatStructArchive.requires_fraction_replacement', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_minimum', full_name='TSK.FormatStructArchive.control_minimum', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_maximum', full_name='TSK.FormatStructArchive.control_maximum', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_increment', full_name='TSK.FormatStructArchive.control_increment', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='control_format_type', full_name='TSK.FormatStructArchive.control_format_type', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slider_orientation', full_name='TSK.FormatStructArchive.slider_orientation', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='slider_position', full_name='TSK.FormatStructArchive.slider_position', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_width', full_name='TSK.FormatStructArchive.decimal_width', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='min_integer_width', full_name='TSK.FormatStructArchive.min_integer_width', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_nonspace_integer_digits', full_name='TSK.FormatStructArchive.num_nonspace_integer_digits', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_nonspace_decimal_digits', full_name='TSK.FormatStructArchive.num_nonspace_decimal_digits', index=29,
      number=30, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_from_right_last_integer', full_name='TSK.FormatStructArchive.index_from_right_last_integer', index=30,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interstitial_strings', full_name='TSK.FormatStructArchive.interstitial_strings', index=31,
      number=32, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inters_str_insertion_indexes', full_name='TSK.FormatStructArchive.inters_str_insertion_indexes', index=32,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_hash_decimal_digits', full_name='TSK.FormatStructArchive.num_hash_decimal_digits', index=33,
      number=34, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_num_decimal_digits', full_name='TSK.FormatStructArchive.total_num_decimal_digits', index=34,
      number=35, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_complex', full_name='TSK.FormatStructArchive.is_complex', index=35,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contains_integer_token', full_name='TSK.FormatStructArchive.contains_integer_token', index=36,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiple_choice_list_initial_value', full_name='TSK.FormatStructArchive.multiple_choice_list_initial_value', index=37,
      number=38, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiple_choice_list_id', full_name='TSK.FormatStructArchive.multiple_choice_list_id', index=38,
      number=39, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_automatic_duration_units', full_name='TSK.FormatStructArchive.use_automatic_duration_units', index=39,
      number=40, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_uid', full_name='TSK.FormatStructArchive.custom_uid', index=40,
      number=41, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_format', full_name='TSK.FormatStructArchive.custom_format', index=41,
      number=42, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uses_plus_sign', full_name='TSK.FormatStructArchive.uses_plus_sign', index=42,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_true_string', full_name='TSK.FormatStructArchive.bool_true_string', index=43,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_false_string', full_name='TSK.FormatStructArchive.bool_false_string', index=44,
      number=45, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(10000, 20000), ],
  oneofs=[
  ],
  serialized_start=5546,
  serialized_end=6902,
)


_CUSTOMFORMATARCHIVE_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='TSK.CustomFormatArchive.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition_type', full_name='TSK.CustomFormatArchive.Condition.condition_type', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition_value', full_name='TSK.CustomFormatArchive.Condition.condition_value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition_format', full_name='TSK.CustomFormatArchive.Condition.condition_format', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition_value_dbl', full_name='TSK.CustomFormatArchive.Condition.condition_value_dbl', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7099,
  serialized_end=7240,
)

_CUSTOMFORMATARCHIVE = _descriptor.Descriptor(
  name='CustomFormatArchive',
  full_name='TSK.CustomFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSK.CustomFormatArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_type_pre_bnc', full_name='TSK.CustomFormatArchive.format_type_pre_bnc', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='default_format', full_name='TSK.CustomFormatArchive.default_format', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='TSK.CustomFormatArchive.conditions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_type', full_name='TSK.CustomFormatArchive.format_type', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CUSTOMFORMATARCHIVE_CONDITION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6905,
  serialized_end=7240,
)


_CUSTOMFORMATLISTARCHIVE = _descriptor.Descriptor(
  name='CustomFormatListArchive',
  full_name='TSK.CustomFormatListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='TSK.CustomFormatListArchive.uuids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_formats', full_name='TSK.CustomFormatListArchive.custom_formats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7242,
  serialized_end=7343,
)


_ANNOTATIONAUTHORARCHIVE = _descriptor.Descriptor(
  name='AnnotationAuthorArchive',
  full_name='TSK.AnnotationAuthorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSK.AnnotationAuthorArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='TSK.AnnotationAuthorArchive.color', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_id', full_name='TSK.AnnotationAuthorArchive.public_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_public_author', full_name='TSK.AnnotationAuthorArchive.is_public_author', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7345,
  serialized_end=7456,
)


_DEPRECATEDCHANGEAUTHORARCHIVE = _descriptor.Descriptor(
  name='DeprecatedChangeAuthorArchive',
  full_name='TSK.DeprecatedChangeAuthorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='TSK.DeprecatedChangeAuthorArchive.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_color', full_name='TSK.DeprecatedChangeAuthorArchive.change_color', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7458,
  serialized_end=7537,
)


_ANNOTATIONAUTHORSTORAGEARCHIVE = _descriptor.Descriptor(
  name='AnnotationAuthorStorageArchive',
  full_name='TSK.AnnotationAuthorStorageArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='annotation_author', full_name='TSK.AnnotationAuthorStorageArchive.annotation_author', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7539,
  serialized_end=7614,
)


_SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE = _descriptor.Descriptor(
  name='SetAnnotationAuthorColorCommandArchive',
  full_name='TSK.SetAnnotationAuthorColorCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.SetAnnotationAuthorColorCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotation_author', full_name='TSK.SetAnnotationAuthorColorCommandArchive.annotation_author', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='color', full_name='TSK.SetAnnotationAuthorColorCommandArchive.color', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_color', full_name='TSK.SetAnnotationAuthorColorCommandArchive.old_color', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7617,
  serialized_end=7794,
)


_COMMANDSELECTIONBEHAVIORARCHIVE = _descriptor.Descriptor(
  name='CommandSelectionBehaviorArchive',
  full_name='TSK.CommandSelectionBehaviorArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='archived_selection', full_name='TSK.CommandSelectionBehaviorArchive.archived_selection', index=0,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archived_old_selection', full_name='TSK.CommandSelectionBehaviorArchive.archived_old_selection', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='archived_new_selection', full_name='TSK.CommandSelectionBehaviorArchive.archived_new_selection', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selection_flags', full_name='TSK.CommandSelectionBehaviorArchive.selection_flags', index=3,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_forward_selection_flags', full_name='TSK.CommandSelectionBehaviorArchive.additional_forward_selection_flags', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_reverse_selection_flags', full_name='TSK.CommandSelectionBehaviorArchive.additional_reverse_selection_flags', index=5,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_selection_path_transformer', full_name='TSK.CommandSelectionBehaviorArchive.forward_selection_path_transformer', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_selection_path_transformer', full_name='TSK.CommandSelectionBehaviorArchive.reverse_selection_path_transformer', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_selection_behaviors', full_name='TSK.CommandSelectionBehaviorArchive.additional_selection_behaviors', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7797,
  serialized_end=8292,
)


_SELECTIONPATHTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='SelectionPathTransformerArchive',
  full_name='TSK.SelectionPathTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection_transformers', full_name='TSK.SelectionPathTransformerArchive.selection_transformers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8294,
  serialized_end=8375,
)


_SELECTIONPATHARCHIVE = _descriptor.Descriptor(
  name='SelectionPathArchive',
  full_name='TSK.SelectionPathArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ordered_selections', full_name='TSK.SelectionPathArchive.ordered_selections', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8377,
  serialized_end=8443,
)


_DOCUMENTSELECTIONARCHIVE = _descriptor.Descriptor(
  name='DocumentSelectionArchive',
  full_name='TSK.DocumentSelectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_root', full_name='TSK.DocumentSelectionArchive.document_root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8445,
  serialized_end=8510,
)


_IDOPERATIONARGS = _descriptor.Descriptor(
  name='IdOperationArgs',
  full_name='TSK.IdOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id_path', full_name='TSK.IdOperationArgs.id_path', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8512,
  serialized_end=8561,
)


_ADDIDOPERATIONARGS = _descriptor.Descriptor(
  name='AddIdOperationArgs',
  full_name='TSK.AddIdOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.AddIdOperationArgs.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSK.AddIdOperationArgs.index', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8563,
  serialized_end=8635,
)


_REMOVEIDOPERATIONARGS = _descriptor.Descriptor(
  name='RemoveIdOperationArgs',
  full_name='TSK.RemoveIdOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.RemoveIdOperationArgs.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSK.RemoveIdOperationArgs.index', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8637,
  serialized_end=8712,
)


_REARRANGEIDOPERATIONARGS = _descriptor.Descriptor(
  name='RearrangeIdOperationArgs',
  full_name='TSK.RearrangeIdOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.RearrangeIdOperationArgs.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_index', full_name='TSK.RearrangeIdOperationArgs.from_index', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_index', full_name='TSK.RearrangeIdOperationArgs.to_index', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8714,
  serialized_end=8815,
)


_IDPLACEMENTOPERATIONARGS = _descriptor.Descriptor(
  name='IdPlacementOperationArgs',
  full_name='TSK.IdPlacementOperationArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.IdPlacementOperationArgs.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_index', full_name='TSK.IdPlacementOperationArgs.from_index', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_index', full_name='TSK.IdPlacementOperationArgs.to_index', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8817,
  serialized_end=8918,
)


_NULLCOMMANDARCHIVE = _descriptor.Descriptor(
  name='NullCommandArchive',
  full_name='TSK.NullCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.NullCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8920,
  serialized_end=8976,
)


_GROUPCOMMITCOMMANDARCHIVE = _descriptor.Descriptor(
  name='GroupCommitCommandArchive',
  full_name='TSK.GroupCommitCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.GroupCommitCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8978,
  serialized_end=9041,
)


_UPGRADEDOCPOSTPROCESSINGCOMMANDARCHIVE = _descriptor.Descriptor(
  name='UpgradeDocPostProcessingCommandArchive',
  full_name='TSK.UpgradeDocPostProcessingCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.UpgradeDocPostProcessingCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9043,
  serialized_end=9119,
)


_INDUCEDCOMMANDCOLLECTIONCOMMITCOMMANDARCHIVE = _descriptor.Descriptor(
  name='InducedCommandCollectionCommitCommandArchive',
  full_name='TSK.InducedCommandCollectionCommitCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.InducedCommandCollectionCommitCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9121,
  serialized_end=9203,
)


_EXECUTETESTBETWEENROLLBACKANDREAPPLYCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ExecuteTestBetweenRollbackAndReapplyCommandArchive',
  full_name='TSK.ExecuteTestBetweenRollbackAndReapplyCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.ExecuteTestBetweenRollbackAndReapplyCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9205,
  serialized_end=9293,
)


_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE = _descriptor.Descriptor(
  name='ChangeDocumentPackageTypeCommandArchive',
  full_name='TSK.ChangeDocumentPackageTypeCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.ChangeDocumentPackageTypeCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_package_type', full_name='TSK.ChangeDocumentPackageTypeCommandArchive.new_package_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_package_type', full_name='TSK.ChangeDocumentPackageTypeCommandArchive.old_package_type', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9296,
  serialized_end=9600,
)


_CREATELOCALSTORAGESNAPSHOTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='CreateLocalStorageSnapshotCommandArchive',
  full_name='TSK.CreateLocalStorageSnapshotCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.CreateLocalStorageSnapshotCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='TSK.CreateLocalStorageSnapshotCommandArchive.snapshot_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9602,
  serialized_end=9701,
)


_BLOCKDIFFSATCURRENTREVISIONCOMMAND = _descriptor.Descriptor(
  name='BlockDiffsAtCurrentRevisionCommand',
  full_name='TSK.BlockDiffsAtCurrentRevisionCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSK.BlockDiffsAtCurrentRevisionCommand.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9703,
  serialized_end=9775,
)


_RANGEADDRESS = _descriptor.Descriptor(
  name='RangeAddress',
  full_name='TSK.RangeAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_identifier', full_name='TSK.RangeAddress.address_identifier', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSK.RangeAddress.range_list', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9777,
  serialized_end=9839,
)


_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='TSK.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSK.Operation.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=6,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noop', full_name='TSK.Operation.noop', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address_identifier', full_name='TSK.Operation.address_identifier', index=2,
      number=3, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_length', full_name='TSK.Operation.insert_length', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preserve_lower_priority_location', full_name='TSK.Operation.preserve_lower_priority_location', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_list', full_name='TSK.Operation.range_list', index=5,
      number=6, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transform_behavior', full_name='TSK.Operation.transform_behavior', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=7,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='property_id', full_name='TSK.Operation.property_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='from_index', full_name='TSK.Operation.from_index', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to_index', full_name='TSK.Operation.to_index', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dominating', full_name='TSK.Operation.dominating', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_count', full_name='TSK.Operation.object_count', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object_counter_space', full_name='TSK.Operation.object_counter_space', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPERATION_OPERATIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9842,
  serialized_end=10332,
)


_OPERATIONTRANSFORMER = _descriptor.Descriptor(
  name='OperationTransformer',
  full_name='TSK.OperationTransformer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='higher_priority', full_name='TSK.OperationTransformer.higher_priority', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='TSK.OperationTransformer.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10334,
  serialized_end=10417,
)


_TRANSFORMERENTRY = _descriptor.Descriptor(
  name='TransformerEntry',
  full_name='TSK.TransformerEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='TSK.TransformerEntry.sequence', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_time', full_name='TSK.TransformerEntry.creation_time', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformer', full_name='TSK.TransformerEntry.transformer', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10419,
  serialized_end=10526,
)


_OUTGOINGCOMMANDQUEUEITEM = _descriptor.Descriptor(
  name='OutgoingCommandQueueItem',
  full_name='TSK.OutgoingCommandQueueItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='TSK.OutgoingCommandQueueItem.command', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialized_json_without_data_base64_encoded_string', full_name='TSK.OutgoingCommandQueueItem.serialized_json_without_data_base64_encoded_string', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialized_json_without_data_base64_encoded_data', full_name='TSK.OutgoingCommandQueueItem.serialized_json_without_data_base64_encoded_data', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_to_data_map_entries', full_name='TSK.OutgoingCommandQueueItem.uuid_to_data_map_entries', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10529,
  serialized_end=10809,
)


_OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY = _descriptor.Descriptor(
  name='OutgoingCommandQueueItemUUIDToDataMapEntry',
  full_name='TSK.OutgoingCommandQueueItemUUIDToDataMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSK.OutgoingCommandQueueItemUUIDToDataMapEntry.uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='TSK.OutgoingCommandQueueItemUUIDToDataMapEntry.data', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10811,
  serialized_end=10914,
)


_COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY = _descriptor.Descriptor(
  name='AcknowledgementObserverEntry',
  full_name='TSK.CollaborationDocumentSessionState.AcknowledgementObserverEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_identifier', full_name='TSK.CollaborationDocumentSessionState.AcknowledgementObserverEntry.command_identifier', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledgement_observers', full_name='TSK.CollaborationDocumentSessionState.AcknowledgementObserverEntry.acknowledgement_observers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12132,
  serialized_end=12252,
)

_COLLABORATIONDOCUMENTSESSIONSTATE = _descriptor.Descriptor(
  name='CollaborationDocumentSessionState',
  full_name='TSK.CollaborationDocumentSessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='collaborator_ids', full_name='TSK.CollaborationDocumentSessionState.collaborator_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rsvp_command_queue_items', full_name='TSK.CollaborationDocumentSessionState.rsvp_command_queue_items', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collaborator_cursor_transformer_entries', full_name='TSK.CollaborationDocumentSessionState.collaborator_cursor_transformer_entries', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='acknowledged_commands_pending_resume_process_diffs', full_name='TSK.CollaborationDocumentSessionState.acknowledged_commands_pending_resume_process_diffs', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unprocessed_commands_pending_resume_process_diffs', full_name='TSK.CollaborationDocumentSessionState.unprocessed_commands_pending_resume_process_diffs', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_acknowledgement_observer_entries', full_name='TSK.CollaborationDocumentSessionState.command_acknowledgement_observer_entries', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transformer_from_unprocessed_command_operations_entries', full_name='TSK.CollaborationDocumentSessionState.transformer_from_unprocessed_command_operations_entries', index=6,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mailbox_request_document_revision_sequence', full_name='TSK.CollaborationDocumentSessionState.mailbox_request_document_revision_sequence', index=7,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mailbox_request_document_revision_identifier', full_name='TSK.CollaborationDocumentSessionState.mailbox_request_document_revision_identifier', index=8,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_send_pending_command_queue_item_was_moved_from_rsvp_command_queue', full_name='TSK.CollaborationDocumentSessionState.last_send_pending_command_queue_item_was_moved_from_rsvp_command_queue', index=9,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_command_send_marker_sequence', full_name='TSK.CollaborationDocumentSessionState.last_command_send_marker_sequence', index=10,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_command_send_marker_identifier', full_name='TSK.CollaborationDocumentSessionState.last_command_send_marker_identifier', index=11,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='skipped_acknowledged_commands_pending_resume_process_diffs', full_name='TSK.CollaborationDocumentSessionState.skipped_acknowledged_commands_pending_resume_process_diffs', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_too_old_command_identifier', full_name='TSK.CollaborationDocumentSessionState.last_too_old_command_identifier', index=13,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unprocessed_operation_entries_pending_resume_process_diffs', full_name='TSK.CollaborationDocumentSessionState.unprocessed_operation_entries_pending_resume_process_diffs', index=14,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_pending_command_queue', full_name='TSK.CollaborationDocumentSessionState.send_pending_command_queue', index=15,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count_of_send_pending_command_queue_items_moved_from_rsvp_queue', full_name='TSK.CollaborationDocumentSessionState.count_of_send_pending_command_queue_items_moved_from_rsvp_queue', index=16,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_enqueued_document_load_command_identifier', full_name='TSK.CollaborationDocumentSessionState.last_enqueued_document_load_command_identifier', index=17,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10917,
  serialized_end=12252,
)


_NATIVECONTENTDESCRIPTION = _descriptor.Descriptor(
  name='NativeContentDescription',
  full_name='TSK.NativeContentDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_name', full_name='TSK.NativeContentDescription.app_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_version', full_name='TSK.NativeContentDescription.app_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_id', full_name='TSK.NativeContentDescription.document_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawable_descriptions', full_name='TSK.NativeContentDescription.drawable_descriptions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12255,
  serialized_end=12388,
)


_STRUCTUREDTEXTIMPORTSETTINGS = _descriptor.Descriptor(
  name='StructuredTextImportSettings',
  full_name='TSK.StructuredTextImportSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSK.StructuredTextImportSettings.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='starting_row', full_name='TSK.StructuredTextImportSettings.starting_row', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decimal_separators', full_name='TSK.StructuredTextImportSettings.decimal_separators', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thousands_separators', full_name='TSK.StructuredTextImportSettings.thousands_separators', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transpose_rows_and_columns', full_name='TSK.StructuredTextImportSettings.transpose_rows_and_columns', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delimiters', full_name='TSK.StructuredTextImportSettings.delimiters', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_qualifiers', full_name='TSK.StructuredTextImportSettings.text_qualifiers', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collapse_consecutive', full_name='TSK.StructuredTextImportSettings.collapse_consecutive', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_offsets', full_name='TSK.StructuredTextImportSettings.column_offsets', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatic_delimiters', full_name='TSK.StructuredTextImportSettings.automatic_delimiters', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='automatic_offsets', full_name='TSK.StructuredTextImportSettings.automatic_offsets', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_encoding', full_name='TSK.StructuredTextImportSettings.source_encoding', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12391,
  serialized_end=12778,
)


_OPERATIONSTORAGECOMMANDOPERATIONSENTRY = _descriptor.Descriptor(
  name='OperationStorageCommandOperationsEntry',
  full_name='TSK.OperationStorageCommandOperationsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_identifier_same_as_revision_identifier', full_name='TSK.OperationStorageCommandOperationsEntry.command_identifier_same_as_revision_identifier', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_identifier', full_name='TSK.OperationStorageCommandOperationsEntry.command_identifier', index=1,
      number=2, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='TSK.OperationStorageCommandOperationsEntry.operations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='server_originated', full_name='TSK.OperationStorageCommandOperationsEntry.server_originated', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='coalesced_command_entry_count', full_name='TSK.OperationStorageCommandOperationsEntry.coalesced_command_entry_count', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12781,
  serialized_end=13007,
)


_OPERATIONSTORAGEENTRY = _descriptor.Descriptor(
  name='OperationStorageEntry',
  full_name='TSK.OperationStorageEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_revision_identifier', full_name='TSK.OperationStorageEntry.document_revision_identifier', index=0,
      number=1, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='document_revision_sequence_delta', full_name='TSK.OperationStorageEntry.document_revision_sequence_delta', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command_operation_entries', full_name='TSK.OperationStorageEntry.command_operation_entries', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first_entry_creation_time', full_name='TSK.OperationStorageEntry.first_entry_creation_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_time_diff_bucket', full_name='TSK.OperationStorageEntry.creation_time_diff_bucket', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13010,
  serialized_end=13263,
)


_OPERATIONSTORAGEENTRYARRAY = _descriptor.Descriptor(
  name='OperationStorageEntryArray',
  full_name='TSK.OperationStorageEntryArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSK.OperationStorageEntryArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13265,
  serialized_end=13331,
)


_OPERATIONSTORAGEENTRYARRAYSEGMENT = _descriptor.Descriptor(
  name='OperationStorageEntryArraySegment',
  full_name='TSK.OperationStorageEntryArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSK.OperationStorageEntryArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSK.OperationStorageEntryArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_document_revision_sequence_before_segment', full_name='TSK.OperationStorageEntryArraySegment.last_document_revision_sequence_before_segment', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_document_revision_sequence', full_name='TSK.OperationStorageEntryArraySegment.last_document_revision_sequence', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segment_first_entry_creation_time', full_name='TSK.OperationStorageEntryArraySegment.segment_first_entry_creation_time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13334,
  serialized_end=13608,
)


_OPERATIONSTORAGE = _descriptor.Descriptor(
  name='OperationStorage',
  full_name='TSK.OperationStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSK.OperationStorage.entries', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_count', full_name='TSK.OperationStorage.operation_count', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_document_revision_sequence', full_name='TSK.OperationStorage.last_document_revision_sequence', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_document_revision_identifier', full_name='TSK.OperationStorage.last_document_revision_identifier', index=3,
      number=4, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_unskippable_document_revision_before_entries_sequence', full_name='TSK.OperationStorage.last_unskippable_document_revision_before_entries_sequence', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_unskippable_document_revision_before_entries_identifier', full_name='TSK.OperationStorage.last_unskippable_document_revision_before_entries_identifier', index=5,
      number=6, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_unskippable_document_revision_in_entries_sequence', full_name='TSK.OperationStorage.last_unskippable_document_revision_in_entries_sequence', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_unskippable_document_revision_in_entries_identifier', full_name='TSK.OperationStorage.last_unskippable_document_revision_in_entries_identifier', index=7,
      number=8, type=6, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='days_with_an_entry', full_name='TSK.OperationStorage.days_with_an_entry', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13611,
  serialized_end=14082,
)


_OUTGOINGCOMMANDQUEUE = _descriptor.Descriptor(
  name='OutgoingCommandQueue',
  full_name='TSK.OutgoingCommandQueue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_object_array', full_name='TSK.OutgoingCommandQueue.large_object_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14084,
  serialized_end=14157,
)


_OUTGOINGCOMMANDQUEUESEGMENT = _descriptor.Descriptor(
  name='OutgoingCommandQueueSegment',
  full_name='TSK.OutgoingCommandQueueSegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_object_array_segment', full_name='TSK.OutgoingCommandQueueSegment.large_object_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14159,
  serialized_end=14254,
)


_DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR = _descriptor.Descriptor(
  name='ContainerUUIDToReferencedDataPair',
  full_name='TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='container_uuid', full_name='TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair.container_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='referenced_data', full_name='TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair.referenced_data', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_count', full_name='TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair.reference_count', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14569,
  serialized_end=14709,
)

_DATAREFERENCERECORD = _descriptor.Descriptor(
  name='DataReferenceRecord',
  full_name='TSK.DataReferenceRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='added_container_uuid_to_referenced_data_pairs', full_name='TSK.DataReferenceRecord.added_container_uuid_to_referenced_data_pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='removed_container_uuid_to_referenced_data_pairs', full_name='TSK.DataReferenceRecord.removed_container_uuid_to_referenced_data_pairs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unbounded_referenced_datas', full_name='TSK.DataReferenceRecord.unbounded_referenced_datas', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14257,
  serialized_end=14709,
)

_TREENODE.fields_by_name['children'].message_type = TSPMessages__pb2._REFERENCE
_TREENODE.fields_by_name['object'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY_SELECTIONBEHAVIORENTRY.fields_by_name['command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY_SELECTIONBEHAVIORENTRY.fields_by_name['command_selection_behavior'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY_SELECTIONBEHAVIORENTRY.containing_type = _COMMANDHISTORY
_COMMANDHISTORY.fields_by_name['commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY.fields_by_name['marked_redo_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY.fields_by_name['pending_preflight_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDHISTORY.fields_by_name['selection_behavior_entries'].message_type = _COMMANDHISTORY_SELECTIONBEHAVIORENTRY
_COLLABORATIONCOMMANDHISTORY.fields_by_name['undo_items'].message_type = _COLLABORATIONCOMMANDHISTORYITEM
_COLLABORATIONCOMMANDHISTORY.fields_by_name['redo_items'].message_type = _COLLABORATIONCOMMANDHISTORYITEM
_COLLABORATIONCOMMANDHISTORY.fields_by_name['local_identifier'].message_type = TSPMessages__pb2._UUID
_COLLABORATIONCOMMANDHISTORY.fields_by_name['undo_transformer_entries'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORY.fields_by_name['redo_transformer_entries'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYITEM.fields_by_name['command'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYITEM.fields_by_name['selection_behavior'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYITEM.fields_by_name['coalescing_group'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYCOALESCINGGROUP.fields_by_name['nodes'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYCOALESCINGGROUPNODE.fields_by_name['command'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYORIGINATINGCOMMANDACKNOWLEDGEMENTOBSERVER.fields_by_name['coalescing_group'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONCOMMANDHISTORYORIGINATINGCOMMANDACKNOWLEDGEMENTOBSERVER.fields_by_name['node'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['annotation_author_storage'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['activity_log_entries'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['collaboration_operation_history'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTARCHIVE.fields_by_name['formatting_symbols'].message_type = _FORMATTINGSYMBOLSARCHIVE
_FORMATTINGSYMBOLSARCHIVE_CURRENCYSYMBOL.containing_type = _FORMATTINGSYMBOLSARCHIVE
_FORMATTINGSYMBOLSARCHIVE.fields_by_name['currency_symbols'].message_type = _FORMATTINGSYMBOLSARCHIVE_CURRENCYSYMBOL
_DOCUMENTSUPPORTCOLLABORATIONSTATE.fields_by_name['collaboration_command_history'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTCOLLABORATIONSTATE.fields_by_name['collaboration_session_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['command_history'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['web_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['collaboration_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['command_selection_behavior_history'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['view_state'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['collaboration_command_history'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSUPPORTARCHIVE.fields_by_name['collaboration_session_state'].message_type = TSPMessages__pb2._REFERENCE
_VIEWSTATEARCHIVE.fields_by_name['view_state_root'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDARCHIVE.fields_by_name['undoRedoState'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDARCHIVE.fields_by_name['undoCollection'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDGROUPARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_COMMANDGROUPARCHIVE.fields_by_name['commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDGROUPARCHIVE.fields_by_name['process_results'].message_type = TSPMessages__pb2._INDEXSET
_INDUCEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_INDUCEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['inducing_command'].message_type = TSPMessages__pb2._REFERENCE
_INDUCEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['induced_commands'].message_type = TSPMessages__pb2._REFERENCE
_INDUCEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['indexes_of_processed_induced_commands'].message_type = TSPMessages__pb2._INDEXSET
_PROPAGATEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_PROPAGATEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['propagatable_command'].message_type = TSPMessages__pb2._REFERENCE
_PROPAGATEDCOMMANDCOLLECTIONARCHIVE.fields_by_name['propagating_command'].message_type = TSPMessages__pb2._REFERENCE
_FINALCOMMANDPAIRARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_FINALCOMMANDPAIRARCHIVE.fields_by_name['command'].message_type = TSPMessages__pb2._REFERENCE
_FINALCOMMANDPAIRARCHIVE.fields_by_name['final_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCONTAINERARCHIVE.fields_by_name['commands'].message_type = TSPMessages__pb2._REFERENCE
_SHUFFLEMAPPINGARCHIVE_ENTRY.containing_type = _SHUFFLEMAPPINGARCHIVE
_SHUFFLEMAPPINGARCHIVE.fields_by_name['entries'].message_type = _SHUFFLEMAPPINGARCHIVE_ENTRY
_PROGRESSIVECOMMANDGROUPARCHIVE.fields_by_name['super'].message_type = _COMMANDGROUPARCHIVE
_FORMATSTRUCTARCHIVE.fields_by_name['inters_str_insertion_indexes'].message_type = TSPMessages__pb2._INDEXSET
_FORMATSTRUCTARCHIVE.fields_by_name['custom_uid'].message_type = TSPMessages__pb2._UUID
_FORMATSTRUCTARCHIVE.fields_by_name['custom_format'].message_type = _CUSTOMFORMATARCHIVE
_CUSTOMFORMATARCHIVE_CONDITION.fields_by_name['condition_format'].message_type = _FORMATSTRUCTARCHIVE
_CUSTOMFORMATARCHIVE_CONDITION.containing_type = _CUSTOMFORMATARCHIVE
_CUSTOMFORMATARCHIVE.fields_by_name['default_format'].message_type = _FORMATSTRUCTARCHIVE
_CUSTOMFORMATARCHIVE.fields_by_name['conditions'].message_type = _CUSTOMFORMATARCHIVE_CONDITION
_CUSTOMFORMATLISTARCHIVE.fields_by_name['uuids'].message_type = TSPMessages__pb2._UUID
_CUSTOMFORMATLISTARCHIVE.fields_by_name['custom_formats'].message_type = _CUSTOMFORMATARCHIVE
_ANNOTATIONAUTHORARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_DEPRECATEDCHANGEAUTHORARCHIVE.fields_by_name['change_color'].message_type = TSPMessages__pb2._COLOR
_ANNOTATIONAUTHORSTORAGEARCHIVE.fields_by_name['annotation_author'].message_type = TSPMessages__pb2._REFERENCE
_SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE.fields_by_name['annotation_author'].message_type = TSPMessages__pb2._REFERENCE
_SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE.fields_by_name['color'].message_type = TSPMessages__pb2._COLOR
_SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE.fields_by_name['old_color'].message_type = TSPMessages__pb2._COLOR
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['archived_selection'].message_type = _SELECTIONPATHARCHIVE
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['archived_old_selection'].message_type = _SELECTIONPATHARCHIVE
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['archived_new_selection'].message_type = _SELECTIONPATHARCHIVE
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['forward_selection_path_transformer'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['reverse_selection_path_transformer'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSELECTIONBEHAVIORARCHIVE.fields_by_name['additional_selection_behaviors'].message_type = TSPMessages__pb2._REFERENCE
_SELECTIONPATHTRANSFORMERARCHIVE.fields_by_name['selection_transformers'].message_type = TSPMessages__pb2._REFERENCE
_SELECTIONPATHARCHIVE.fields_by_name['ordered_selections'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSELECTIONARCHIVE.fields_by_name['document_root'].message_type = TSPMessages__pb2._REFERENCE
_IDOPERATIONARGS.fields_by_name['id_path'].message_type = TSPMessages__pb2._UUIDPATH
_ADDIDOPERATIONARGS.fields_by_name['super'].message_type = _IDOPERATIONARGS
_REMOVEIDOPERATIONARGS.fields_by_name['super'].message_type = _IDOPERATIONARGS
_REARRANGEIDOPERATIONARGS.fields_by_name['super'].message_type = _IDOPERATIONARGS
_IDPLACEMENTOPERATIONARGS.fields_by_name['super'].message_type = _IDOPERATIONARGS
_NULLCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_GROUPCOMMITCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_UPGRADEDOCPOSTPROCESSINGCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_INDUCEDCOMMANDCOLLECTIONCOMMITCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_EXECUTETESTBETWEENROLLBACKANDREAPPLYCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE.fields_by_name['new_package_type'].enum_type = _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE
_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE.fields_by_name['old_package_type'].enum_type = _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE
_CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE_PACKAGETYPE.containing_type = _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE
_CREATELOCALSTORAGESNAPSHOTCOMMANDARCHIVE.fields_by_name['super'].message_type = _COMMANDARCHIVE
_BLOCKDIFFSATCURRENTREVISIONCOMMAND.fields_by_name['super'].message_type = _COMMANDARCHIVE
_OPERATION.fields_by_name['type'].enum_type = _OPERATION_OPERATIONTYPE
_OPERATION_OPERATIONTYPE.containing_type = _OPERATION
_OPERATIONTRANSFORMER.fields_by_name['operations'].message_type = _OPERATION
_TRANSFORMERENTRY.fields_by_name['transformer'].message_type = _OPERATIONTRANSFORMER
_OUTGOINGCOMMANDQUEUEITEM.fields_by_name['command'].message_type = TSPMessages__pb2._REFERENCE
_OUTGOINGCOMMANDQUEUEITEM.fields_by_name['serialized_json_without_data_base64_encoded_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_OUTGOINGCOMMANDQUEUEITEM.fields_by_name['uuid_to_data_map_entries'].message_type = _OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY
_OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY.fields_by_name['data'].message_type = TSPMessages__pb2._DATAREFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY.fields_by_name['command_identifier'].message_type = TSPMessages__pb2._UUID
_COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY.fields_by_name['acknowledgement_observers'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY.containing_type = _COLLABORATIONDOCUMENTSESSIONSTATE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['rsvp_command_queue_items'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['collaborator_cursor_transformer_entries'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['acknowledged_commands_pending_resume_process_diffs'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['unprocessed_commands_pending_resume_process_diffs'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['command_acknowledgement_observer_entries'].message_type = _COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['transformer_from_unprocessed_command_operations_entries'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['skipped_acknowledged_commands_pending_resume_process_diffs'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['last_too_old_command_identifier'].message_type = TSPMessages__pb2._UUID
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['unprocessed_operation_entries_pending_resume_process_diffs'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['send_pending_command_queue'].message_type = TSPMessages__pb2._REFERENCE
_COLLABORATIONDOCUMENTSESSIONSTATE.fields_by_name['last_enqueued_document_load_command_identifier'].message_type = TSPMessages__pb2._UUID
_NATIVECONTENTDESCRIPTION.fields_by_name['drawable_descriptions'].message_type = TSPMessages__pb2._REFERENCE
_STRUCTUREDTEXTIMPORTSETTINGS.fields_by_name['type'].enum_type = _STRUCTUREDTEXTIMPORTTYPE
_STRUCTUREDTEXTIMPORTSETTINGS.fields_by_name['column_offsets'].message_type = TSPMessages__pb2._INDEXSET
_OPERATIONSTORAGECOMMANDOPERATIONSENTRY.fields_by_name['operations'].message_type = _OPERATION
_OPERATIONSTORAGEENTRY.fields_by_name['command_operation_entries'].message_type = _OPERATIONSTORAGECOMMANDOPERATIONSENTRY
_OPERATIONSTORAGEENTRYARRAY.fields_by_name['large_array'].message_type = TSPMessages__pb2._LARGEARRAY
_OPERATIONSTORAGEENTRYARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = TSPMessages__pb2._LARGEARRAYSEGMENT
_OPERATIONSTORAGEENTRYARRAYSEGMENT.fields_by_name['elements'].message_type = _OPERATIONSTORAGEENTRY
_OPERATIONSTORAGE.fields_by_name['entries'].message_type = TSPMessages__pb2._REFERENCE
_OPERATIONSTORAGE.fields_by_name['days_with_an_entry'].message_type = TSPMessages__pb2._INDEXSET
_OUTGOINGCOMMANDQUEUE.fields_by_name['large_object_array'].message_type = TSPMessages__pb2._LARGEOBJECTARRAY
_OUTGOINGCOMMANDQUEUESEGMENT.fields_by_name['large_object_array_segment'].message_type = TSPMessages__pb2._LARGEOBJECTARRAYSEGMENT
_DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR.fields_by_name['container_uuid'].message_type = TSPMessages__pb2._UUID
_DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR.fields_by_name['referenced_data'].message_type = TSPMessages__pb2._DATAREFERENCE
_DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR.containing_type = _DATAREFERENCERECORD
_DATAREFERENCERECORD.fields_by_name['added_container_uuid_to_referenced_data_pairs'].message_type = _DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR
_DATAREFERENCERECORD.fields_by_name['removed_container_uuid_to_referenced_data_pairs'].message_type = _DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR
_DATAREFERENCERECORD.fields_by_name['unbounded_referenced_datas'].message_type = TSPMessages__pb2._DATAREFERENCE
DESCRIPTOR.message_types_by_name['TreeNode'] = _TREENODE
DESCRIPTOR.message_types_by_name['CommandHistory'] = _COMMANDHISTORY
DESCRIPTOR.message_types_by_name['CollaborationCommandHistory'] = _COLLABORATIONCOMMANDHISTORY
DESCRIPTOR.message_types_by_name['CollaborationCommandHistoryItem'] = _COLLABORATIONCOMMANDHISTORYITEM
DESCRIPTOR.message_types_by_name['CollaborationCommandHistoryCoalescingGroup'] = _COLLABORATIONCOMMANDHISTORYCOALESCINGGROUP
DESCRIPTOR.message_types_by_name['CollaborationCommandHistoryCoalescingGroupNode'] = _COLLABORATIONCOMMANDHISTORYCOALESCINGGROUPNODE
DESCRIPTOR.message_types_by_name['CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver'] = _COLLABORATIONCOMMANDHISTORYORIGINATINGCOMMANDACKNOWLEDGEMENTOBSERVER
DESCRIPTOR.message_types_by_name['DocumentArchive'] = _DOCUMENTARCHIVE
DESCRIPTOR.message_types_by_name['FormattingSymbolsArchive'] = _FORMATTINGSYMBOLSARCHIVE
DESCRIPTOR.message_types_by_name['DocumentSupportCollaborationState'] = _DOCUMENTSUPPORTCOLLABORATIONSTATE
DESCRIPTOR.message_types_by_name['DocumentSupportArchive'] = _DOCUMENTSUPPORTARCHIVE
DESCRIPTOR.message_types_by_name['ViewStateArchive'] = _VIEWSTATEARCHIVE
DESCRIPTOR.message_types_by_name['CommandArchive'] = _COMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandGroupArchive'] = _COMMANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['InducedCommandCollectionArchive'] = _INDUCEDCOMMANDCOLLECTIONARCHIVE
DESCRIPTOR.message_types_by_name['PropagatedCommandCollectionArchive'] = _PROPAGATEDCOMMANDCOLLECTIONARCHIVE
DESCRIPTOR.message_types_by_name['FinalCommandPairArchive'] = _FINALCOMMANDPAIRARCHIVE
DESCRIPTOR.message_types_by_name['CommandContainerArchive'] = _COMMANDCONTAINERARCHIVE
DESCRIPTOR.message_types_by_name['ShuffleMappingArchive'] = _SHUFFLEMAPPINGARCHIVE
DESCRIPTOR.message_types_by_name['ProgressiveCommandGroupArchive'] = _PROGRESSIVECOMMANDGROUPARCHIVE
DESCRIPTOR.message_types_by_name['FormatStructArchive'] = _FORMATSTRUCTARCHIVE
DESCRIPTOR.message_types_by_name['CustomFormatArchive'] = _CUSTOMFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CustomFormatListArchive'] = _CUSTOMFORMATLISTARCHIVE
DESCRIPTOR.message_types_by_name['AnnotationAuthorArchive'] = _ANNOTATIONAUTHORARCHIVE
DESCRIPTOR.message_types_by_name['DeprecatedChangeAuthorArchive'] = _DEPRECATEDCHANGEAUTHORARCHIVE
DESCRIPTOR.message_types_by_name['AnnotationAuthorStorageArchive'] = _ANNOTATIONAUTHORSTORAGEARCHIVE
DESCRIPTOR.message_types_by_name['SetAnnotationAuthorColorCommandArchive'] = _SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandSelectionBehaviorArchive'] = _COMMANDSELECTIONBEHAVIORARCHIVE
DESCRIPTOR.message_types_by_name['SelectionPathTransformerArchive'] = _SELECTIONPATHTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['SelectionPathArchive'] = _SELECTIONPATHARCHIVE
DESCRIPTOR.message_types_by_name['DocumentSelectionArchive'] = _DOCUMENTSELECTIONARCHIVE
DESCRIPTOR.message_types_by_name['IdOperationArgs'] = _IDOPERATIONARGS
DESCRIPTOR.message_types_by_name['AddIdOperationArgs'] = _ADDIDOPERATIONARGS
DESCRIPTOR.message_types_by_name['RemoveIdOperationArgs'] = _REMOVEIDOPERATIONARGS
DESCRIPTOR.message_types_by_name['RearrangeIdOperationArgs'] = _REARRANGEIDOPERATIONARGS
DESCRIPTOR.message_types_by_name['IdPlacementOperationArgs'] = _IDPLACEMENTOPERATIONARGS
DESCRIPTOR.message_types_by_name['NullCommandArchive'] = _NULLCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['GroupCommitCommandArchive'] = _GROUPCOMMITCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['UpgradeDocPostProcessingCommandArchive'] = _UPGRADEDOCPOSTPROCESSINGCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['InducedCommandCollectionCommitCommandArchive'] = _INDUCEDCOMMANDCOLLECTIONCOMMITCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ExecuteTestBetweenRollbackAndReapplyCommandArchive'] = _EXECUTETESTBETWEENROLLBACKANDREAPPLYCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['ChangeDocumentPackageTypeCommandArchive'] = _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CreateLocalStorageSnapshotCommandArchive'] = _CREATELOCALSTORAGESNAPSHOTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['BlockDiffsAtCurrentRevisionCommand'] = _BLOCKDIFFSATCURRENTREVISIONCOMMAND
DESCRIPTOR.message_types_by_name['RangeAddress'] = _RANGEADDRESS
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
DESCRIPTOR.message_types_by_name['OperationTransformer'] = _OPERATIONTRANSFORMER
DESCRIPTOR.message_types_by_name['TransformerEntry'] = _TRANSFORMERENTRY
DESCRIPTOR.message_types_by_name['OutgoingCommandQueueItem'] = _OUTGOINGCOMMANDQUEUEITEM
DESCRIPTOR.message_types_by_name['OutgoingCommandQueueItemUUIDToDataMapEntry'] = _OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY
DESCRIPTOR.message_types_by_name['CollaborationDocumentSessionState'] = _COLLABORATIONDOCUMENTSESSIONSTATE
DESCRIPTOR.message_types_by_name['NativeContentDescription'] = _NATIVECONTENTDESCRIPTION
DESCRIPTOR.message_types_by_name['StructuredTextImportSettings'] = _STRUCTUREDTEXTIMPORTSETTINGS
DESCRIPTOR.message_types_by_name['OperationStorageCommandOperationsEntry'] = _OPERATIONSTORAGECOMMANDOPERATIONSENTRY
DESCRIPTOR.message_types_by_name['OperationStorageEntry'] = _OPERATIONSTORAGEENTRY
DESCRIPTOR.message_types_by_name['OperationStorageEntryArray'] = _OPERATIONSTORAGEENTRYARRAY
DESCRIPTOR.message_types_by_name['OperationStorageEntryArraySegment'] = _OPERATIONSTORAGEENTRYARRAYSEGMENT
DESCRIPTOR.message_types_by_name['OperationStorage'] = _OPERATIONSTORAGE
DESCRIPTOR.message_types_by_name['OutgoingCommandQueue'] = _OUTGOINGCOMMANDQUEUE
DESCRIPTOR.message_types_by_name['OutgoingCommandQueueSegment'] = _OUTGOINGCOMMANDQUEUESEGMENT
DESCRIPTOR.message_types_by_name['DataReferenceRecord'] = _DATAREFERENCERECORD
DESCRIPTOR.enum_types_by_name['StructuredTextImportType'] = _STRUCTUREDTEXTIMPORTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TreeNode = _reflection.GeneratedProtocolMessageType('TreeNode', (_message.Message,), dict(
  DESCRIPTOR = _TREENODE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.TreeNode)
  ))
_sym_db.RegisterMessage(TreeNode)

CommandHistory = _reflection.GeneratedProtocolMessageType('CommandHistory', (_message.Message,), dict(

  SelectionBehaviorEntry = _reflection.GeneratedProtocolMessageType('SelectionBehaviorEntry', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDHISTORY_SELECTIONBEHAVIORENTRY,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.CommandHistory.SelectionBehaviorEntry)
    ))
  ,
  DESCRIPTOR = _COMMANDHISTORY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CommandHistory)
  ))
_sym_db.RegisterMessage(CommandHistory)
_sym_db.RegisterMessage(CommandHistory.SelectionBehaviorEntry)

CollaborationCommandHistory = _reflection.GeneratedProtocolMessageType('CollaborationCommandHistory', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATIONCOMMANDHISTORY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationCommandHistory)
  ))
_sym_db.RegisterMessage(CollaborationCommandHistory)

CollaborationCommandHistoryItem = _reflection.GeneratedProtocolMessageType('CollaborationCommandHistoryItem', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATIONCOMMANDHISTORYITEM,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationCommandHistoryItem)
  ))
_sym_db.RegisterMessage(CollaborationCommandHistoryItem)

CollaborationCommandHistoryCoalescingGroup = _reflection.GeneratedProtocolMessageType('CollaborationCommandHistoryCoalescingGroup', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATIONCOMMANDHISTORYCOALESCINGGROUP,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationCommandHistoryCoalescingGroup)
  ))
_sym_db.RegisterMessage(CollaborationCommandHistoryCoalescingGroup)

CollaborationCommandHistoryCoalescingGroupNode = _reflection.GeneratedProtocolMessageType('CollaborationCommandHistoryCoalescingGroupNode', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATIONCOMMANDHISTORYCOALESCINGGROUPNODE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationCommandHistoryCoalescingGroupNode)
  ))
_sym_db.RegisterMessage(CollaborationCommandHistoryCoalescingGroupNode)

CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver = _reflection.GeneratedProtocolMessageType('CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver', (_message.Message,), dict(
  DESCRIPTOR = _COLLABORATIONCOMMANDHISTORYORIGINATINGCOMMANDACKNOWLEDGEMENTOBSERVER,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver)
  ))
_sym_db.RegisterMessage(CollaborationCommandHistoryOriginatingCommandAcknowledgementObserver)

DocumentArchive = _reflection.GeneratedProtocolMessageType('DocumentArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DocumentArchive)
  ))
_sym_db.RegisterMessage(DocumentArchive)

FormattingSymbolsArchive = _reflection.GeneratedProtocolMessageType('FormattingSymbolsArchive', (_message.Message,), dict(

  CurrencySymbol = _reflection.GeneratedProtocolMessageType('CurrencySymbol', (_message.Message,), dict(
    DESCRIPTOR = _FORMATTINGSYMBOLSARCHIVE_CURRENCYSYMBOL,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.FormattingSymbolsArchive.CurrencySymbol)
    ))
  ,
  DESCRIPTOR = _FORMATTINGSYMBOLSARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.FormattingSymbolsArchive)
  ))
_sym_db.RegisterMessage(FormattingSymbolsArchive)
_sym_db.RegisterMessage(FormattingSymbolsArchive.CurrencySymbol)

DocumentSupportCollaborationState = _reflection.GeneratedProtocolMessageType('DocumentSupportCollaborationState', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTSUPPORTCOLLABORATIONSTATE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DocumentSupportCollaborationState)
  ))
_sym_db.RegisterMessage(DocumentSupportCollaborationState)

DocumentSupportArchive = _reflection.GeneratedProtocolMessageType('DocumentSupportArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTSUPPORTARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DocumentSupportArchive)
  ))
_sym_db.RegisterMessage(DocumentSupportArchive)

ViewStateArchive = _reflection.GeneratedProtocolMessageType('ViewStateArchive', (_message.Message,), dict(
  DESCRIPTOR = _VIEWSTATEARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.ViewStateArchive)
  ))
_sym_db.RegisterMessage(ViewStateArchive)

CommandArchive = _reflection.GeneratedProtocolMessageType('CommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CommandArchive)
  ))
_sym_db.RegisterMessage(CommandArchive)

CommandGroupArchive = _reflection.GeneratedProtocolMessageType('CommandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDGROUPARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CommandGroupArchive)
  ))
_sym_db.RegisterMessage(CommandGroupArchive)

InducedCommandCollectionArchive = _reflection.GeneratedProtocolMessageType('InducedCommandCollectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDCOMMANDCOLLECTIONARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.InducedCommandCollectionArchive)
  ))
_sym_db.RegisterMessage(InducedCommandCollectionArchive)

PropagatedCommandCollectionArchive = _reflection.GeneratedProtocolMessageType('PropagatedCommandCollectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROPAGATEDCOMMANDCOLLECTIONARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.PropagatedCommandCollectionArchive)
  ))
_sym_db.RegisterMessage(PropagatedCommandCollectionArchive)

FinalCommandPairArchive = _reflection.GeneratedProtocolMessageType('FinalCommandPairArchive', (_message.Message,), dict(
  DESCRIPTOR = _FINALCOMMANDPAIRARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.FinalCommandPairArchive)
  ))
_sym_db.RegisterMessage(FinalCommandPairArchive)

CommandContainerArchive = _reflection.GeneratedProtocolMessageType('CommandContainerArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCONTAINERARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CommandContainerArchive)
  ))
_sym_db.RegisterMessage(CommandContainerArchive)

ShuffleMappingArchive = _reflection.GeneratedProtocolMessageType('ShuffleMappingArchive', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _SHUFFLEMAPPINGARCHIVE_ENTRY,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.ShuffleMappingArchive.Entry)
    ))
  ,
  DESCRIPTOR = _SHUFFLEMAPPINGARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.ShuffleMappingArchive)
  ))
_sym_db.RegisterMessage(ShuffleMappingArchive)
_sym_db.RegisterMessage(ShuffleMappingArchive.Entry)

ProgressiveCommandGroupArchive = _reflection.GeneratedProtocolMessageType('ProgressiveCommandGroupArchive', (_message.Message,), dict(
  DESCRIPTOR = _PROGRESSIVECOMMANDGROUPARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.ProgressiveCommandGroupArchive)
  ))
_sym_db.RegisterMessage(ProgressiveCommandGroupArchive)

FormatStructArchive = _reflection.GeneratedProtocolMessageType('FormatStructArchive', (_message.Message,), dict(
  DESCRIPTOR = _FORMATSTRUCTARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.FormatStructArchive)
  ))
_sym_db.RegisterMessage(FormatStructArchive)

CustomFormatArchive = _reflection.GeneratedProtocolMessageType('CustomFormatArchive', (_message.Message,), dict(

  Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), dict(
    DESCRIPTOR = _CUSTOMFORMATARCHIVE_CONDITION,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.CustomFormatArchive.Condition)
    ))
  ,
  DESCRIPTOR = _CUSTOMFORMATARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CustomFormatArchive)
  ))
_sym_db.RegisterMessage(CustomFormatArchive)
_sym_db.RegisterMessage(CustomFormatArchive.Condition)

CustomFormatListArchive = _reflection.GeneratedProtocolMessageType('CustomFormatListArchive', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMFORMATLISTARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CustomFormatListArchive)
  ))
_sym_db.RegisterMessage(CustomFormatListArchive)

AnnotationAuthorArchive = _reflection.GeneratedProtocolMessageType('AnnotationAuthorArchive', (_message.Message,), dict(
  DESCRIPTOR = _ANNOTATIONAUTHORARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.AnnotationAuthorArchive)
  ))
_sym_db.RegisterMessage(AnnotationAuthorArchive)

DeprecatedChangeAuthorArchive = _reflection.GeneratedProtocolMessageType('DeprecatedChangeAuthorArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPRECATEDCHANGEAUTHORARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DeprecatedChangeAuthorArchive)
  ))
_sym_db.RegisterMessage(DeprecatedChangeAuthorArchive)

AnnotationAuthorStorageArchive = _reflection.GeneratedProtocolMessageType('AnnotationAuthorStorageArchive', (_message.Message,), dict(
  DESCRIPTOR = _ANNOTATIONAUTHORSTORAGEARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.AnnotationAuthorStorageArchive)
  ))
_sym_db.RegisterMessage(AnnotationAuthorStorageArchive)

SetAnnotationAuthorColorCommandArchive = _reflection.GeneratedProtocolMessageType('SetAnnotationAuthorColorCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _SETANNOTATIONAUTHORCOLORCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.SetAnnotationAuthorColorCommandArchive)
  ))
_sym_db.RegisterMessage(SetAnnotationAuthorColorCommandArchive)

CommandSelectionBehaviorArchive = _reflection.GeneratedProtocolMessageType('CommandSelectionBehaviorArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSELECTIONBEHAVIORARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CommandSelectionBehaviorArchive)
  ))
_sym_db.RegisterMessage(CommandSelectionBehaviorArchive)

SelectionPathTransformerArchive = _reflection.GeneratedProtocolMessageType('SelectionPathTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _SELECTIONPATHTRANSFORMERARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.SelectionPathTransformerArchive)
  ))
_sym_db.RegisterMessage(SelectionPathTransformerArchive)

SelectionPathArchive = _reflection.GeneratedProtocolMessageType('SelectionPathArchive', (_message.Message,), dict(
  DESCRIPTOR = _SELECTIONPATHARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.SelectionPathArchive)
  ))
_sym_db.RegisterMessage(SelectionPathArchive)

DocumentSelectionArchive = _reflection.GeneratedProtocolMessageType('DocumentSelectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _DOCUMENTSELECTIONARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DocumentSelectionArchive)
  ))
_sym_db.RegisterMessage(DocumentSelectionArchive)

IdOperationArgs = _reflection.GeneratedProtocolMessageType('IdOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _IDOPERATIONARGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.IdOperationArgs)
  ))
_sym_db.RegisterMessage(IdOperationArgs)

AddIdOperationArgs = _reflection.GeneratedProtocolMessageType('AddIdOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _ADDIDOPERATIONARGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.AddIdOperationArgs)
  ))
_sym_db.RegisterMessage(AddIdOperationArgs)

RemoveIdOperationArgs = _reflection.GeneratedProtocolMessageType('RemoveIdOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _REMOVEIDOPERATIONARGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.RemoveIdOperationArgs)
  ))
_sym_db.RegisterMessage(RemoveIdOperationArgs)

RearrangeIdOperationArgs = _reflection.GeneratedProtocolMessageType('RearrangeIdOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _REARRANGEIDOPERATIONARGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.RearrangeIdOperationArgs)
  ))
_sym_db.RegisterMessage(RearrangeIdOperationArgs)

IdPlacementOperationArgs = _reflection.GeneratedProtocolMessageType('IdPlacementOperationArgs', (_message.Message,), dict(
  DESCRIPTOR = _IDPLACEMENTOPERATIONARGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.IdPlacementOperationArgs)
  ))
_sym_db.RegisterMessage(IdPlacementOperationArgs)

NullCommandArchive = _reflection.GeneratedProtocolMessageType('NullCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _NULLCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.NullCommandArchive)
  ))
_sym_db.RegisterMessage(NullCommandArchive)

GroupCommitCommandArchive = _reflection.GeneratedProtocolMessageType('GroupCommitCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _GROUPCOMMITCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.GroupCommitCommandArchive)
  ))
_sym_db.RegisterMessage(GroupCommitCommandArchive)

UpgradeDocPostProcessingCommandArchive = _reflection.GeneratedProtocolMessageType('UpgradeDocPostProcessingCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _UPGRADEDOCPOSTPROCESSINGCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.UpgradeDocPostProcessingCommandArchive)
  ))
_sym_db.RegisterMessage(UpgradeDocPostProcessingCommandArchive)

InducedCommandCollectionCommitCommandArchive = _reflection.GeneratedProtocolMessageType('InducedCommandCollectionCommitCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _INDUCEDCOMMANDCOLLECTIONCOMMITCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.InducedCommandCollectionCommitCommandArchive)
  ))
_sym_db.RegisterMessage(InducedCommandCollectionCommitCommandArchive)

ExecuteTestBetweenRollbackAndReapplyCommandArchive = _reflection.GeneratedProtocolMessageType('ExecuteTestBetweenRollbackAndReapplyCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTETESTBETWEENROLLBACKANDREAPPLYCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.ExecuteTestBetweenRollbackAndReapplyCommandArchive)
  ))
_sym_db.RegisterMessage(ExecuteTestBetweenRollbackAndReapplyCommandArchive)

ChangeDocumentPackageTypeCommandArchive = _reflection.GeneratedProtocolMessageType('ChangeDocumentPackageTypeCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHANGEDOCUMENTPACKAGETYPECOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.ChangeDocumentPackageTypeCommandArchive)
  ))
_sym_db.RegisterMessage(ChangeDocumentPackageTypeCommandArchive)

CreateLocalStorageSnapshotCommandArchive = _reflection.GeneratedProtocolMessageType('CreateLocalStorageSnapshotCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CREATELOCALSTORAGESNAPSHOTCOMMANDARCHIVE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CreateLocalStorageSnapshotCommandArchive)
  ))
_sym_db.RegisterMessage(CreateLocalStorageSnapshotCommandArchive)

BlockDiffsAtCurrentRevisionCommand = _reflection.GeneratedProtocolMessageType('BlockDiffsAtCurrentRevisionCommand', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKDIFFSATCURRENTREVISIONCOMMAND,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.BlockDiffsAtCurrentRevisionCommand)
  ))
_sym_db.RegisterMessage(BlockDiffsAtCurrentRevisionCommand)

RangeAddress = _reflection.GeneratedProtocolMessageType('RangeAddress', (_message.Message,), dict(
  DESCRIPTOR = _RANGEADDRESS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.RangeAddress)
  ))
_sym_db.RegisterMessage(RangeAddress)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), dict(
  DESCRIPTOR = _OPERATION,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.Operation)
  ))
_sym_db.RegisterMessage(Operation)

OperationTransformer = _reflection.GeneratedProtocolMessageType('OperationTransformer', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONTRANSFORMER,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationTransformer)
  ))
_sym_db.RegisterMessage(OperationTransformer)

TransformerEntry = _reflection.GeneratedProtocolMessageType('TransformerEntry', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFORMERENTRY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.TransformerEntry)
  ))
_sym_db.RegisterMessage(TransformerEntry)

OutgoingCommandQueueItem = _reflection.GeneratedProtocolMessageType('OutgoingCommandQueueItem', (_message.Message,), dict(
  DESCRIPTOR = _OUTGOINGCOMMANDQUEUEITEM,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OutgoingCommandQueueItem)
  ))
_sym_db.RegisterMessage(OutgoingCommandQueueItem)

OutgoingCommandQueueItemUUIDToDataMapEntry = _reflection.GeneratedProtocolMessageType('OutgoingCommandQueueItemUUIDToDataMapEntry', (_message.Message,), dict(
  DESCRIPTOR = _OUTGOINGCOMMANDQUEUEITEMUUIDTODATAMAPENTRY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OutgoingCommandQueueItemUUIDToDataMapEntry)
  ))
_sym_db.RegisterMessage(OutgoingCommandQueueItemUUIDToDataMapEntry)

CollaborationDocumentSessionState = _reflection.GeneratedProtocolMessageType('CollaborationDocumentSessionState', (_message.Message,), dict(

  AcknowledgementObserverEntry = _reflection.GeneratedProtocolMessageType('AcknowledgementObserverEntry', (_message.Message,), dict(
    DESCRIPTOR = _COLLABORATIONDOCUMENTSESSIONSTATE_ACKNOWLEDGEMENTOBSERVERENTRY,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.CollaborationDocumentSessionState.AcknowledgementObserverEntry)
    ))
  ,
  DESCRIPTOR = _COLLABORATIONDOCUMENTSESSIONSTATE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.CollaborationDocumentSessionState)
  ))
_sym_db.RegisterMessage(CollaborationDocumentSessionState)
_sym_db.RegisterMessage(CollaborationDocumentSessionState.AcknowledgementObserverEntry)

NativeContentDescription = _reflection.GeneratedProtocolMessageType('NativeContentDescription', (_message.Message,), dict(
  DESCRIPTOR = _NATIVECONTENTDESCRIPTION,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.NativeContentDescription)
  ))
_sym_db.RegisterMessage(NativeContentDescription)

StructuredTextImportSettings = _reflection.GeneratedProtocolMessageType('StructuredTextImportSettings', (_message.Message,), dict(
  DESCRIPTOR = _STRUCTUREDTEXTIMPORTSETTINGS,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.StructuredTextImportSettings)
  ))
_sym_db.RegisterMessage(StructuredTextImportSettings)

OperationStorageCommandOperationsEntry = _reflection.GeneratedProtocolMessageType('OperationStorageCommandOperationsEntry', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONSTORAGECOMMANDOPERATIONSENTRY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationStorageCommandOperationsEntry)
  ))
_sym_db.RegisterMessage(OperationStorageCommandOperationsEntry)

OperationStorageEntry = _reflection.GeneratedProtocolMessageType('OperationStorageEntry', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONSTORAGEENTRY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationStorageEntry)
  ))
_sym_db.RegisterMessage(OperationStorageEntry)

OperationStorageEntryArray = _reflection.GeneratedProtocolMessageType('OperationStorageEntryArray', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONSTORAGEENTRYARRAY,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationStorageEntryArray)
  ))
_sym_db.RegisterMessage(OperationStorageEntryArray)

OperationStorageEntryArraySegment = _reflection.GeneratedProtocolMessageType('OperationStorageEntryArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONSTORAGEENTRYARRAYSEGMENT,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationStorageEntryArraySegment)
  ))
_sym_db.RegisterMessage(OperationStorageEntryArraySegment)

OperationStorage = _reflection.GeneratedProtocolMessageType('OperationStorage', (_message.Message,), dict(
  DESCRIPTOR = _OPERATIONSTORAGE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OperationStorage)
  ))
_sym_db.RegisterMessage(OperationStorage)

OutgoingCommandQueue = _reflection.GeneratedProtocolMessageType('OutgoingCommandQueue', (_message.Message,), dict(
  DESCRIPTOR = _OUTGOINGCOMMANDQUEUE,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OutgoingCommandQueue)
  ))
_sym_db.RegisterMessage(OutgoingCommandQueue)

OutgoingCommandQueueSegment = _reflection.GeneratedProtocolMessageType('OutgoingCommandQueueSegment', (_message.Message,), dict(
  DESCRIPTOR = _OUTGOINGCOMMANDQUEUESEGMENT,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.OutgoingCommandQueueSegment)
  ))
_sym_db.RegisterMessage(OutgoingCommandQueueSegment)

DataReferenceRecord = _reflection.GeneratedProtocolMessageType('DataReferenceRecord', (_message.Message,), dict(

  ContainerUUIDToReferencedDataPair = _reflection.GeneratedProtocolMessageType('ContainerUUIDToReferencedDataPair', (_message.Message,), dict(
    DESCRIPTOR = _DATAREFERENCERECORD_CONTAINERUUIDTOREFERENCEDDATAPAIR,
    __module__ = 'TSKArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSK.DataReferenceRecord.ContainerUUIDToReferencedDataPair)
    ))
  ,
  DESCRIPTOR = _DATAREFERENCERECORD,
  __module__ = 'TSKArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSK.DataReferenceRecord)
  ))
_sym_db.RegisterMessage(DataReferenceRecord)
_sym_db.RegisterMessage(DataReferenceRecord.ContainerUUIDToReferencedDataPair)


_COMMANDHISTORY.fields_by_name['marked_redo_commands']._options = None
_COMMANDHISTORY.fields_by_name['pending_preflight_command']._options = None
_DOCUMENTSUPPORTARCHIVE.fields_by_name['command_selection_behavior_history']._options = None
_DOCUMENTSUPPORTARCHIVE.fields_by_name['view_state']._options = None
_DOCUMENTSUPPORTARCHIVE.fields_by_name['collaboration_command_history']._options = None
_DOCUMENTSUPPORTARCHIVE.fields_by_name['collaboration_session_state']._options = None
_COMMANDARCHIVE.fields_by_name['undoRedoState']._options = None
# @@protoc_insertion_point(module_scope)
